import logging

import src.RhcsQeSdk.core.cli.fabfile as fabfile
from src.RhcsQeSdk.core.utilities import core_utils

logger = logging.getLogger(__name__)
logger.setLevel(logging.DEBUG)

formatter = logging.Formatter(
    "%(asctime)s - %(levelname)s - %(name)s:%(lineno)d - %(message)s"
)

stream_handler = logging.StreamHandler()
stream_handler.setFormatter(formatter)
stream_handler.setLevel(logging.DEBUG)
logger.addHandler(stream_handler)


class Log:
    """This module provides CLI interface to manage rgw log object management."""

    def __init__(self, base_cmd):
        self.base_cmd = base_cmd + " log"

    def list_(self, **kw):
        """
        List log objects.

        Args:
            None

        Returns:
            Dict(str)
            A mapping of host strings to the given task's return value for that host's execution run.
        """
        kw = kw.get("kw")
        cmd = self.base_cmd + " list"
        logger.info(f"Running command {cmd}")
        return fabfile.run_command(cmd, config=kw.get("env_config"))

    def show(self, **kw):
        """
        Dump a log from specific object or (bucket + date + bucket-id)

        Args:
            object(str): name of the object
            bucket(str): name of the bucket(optional)
            date(str): date(optional)
            bucket-id(str): specify the bucket id(optional)

        Returns:
            Dict(str)
            A mapping of host strings to the given task's return value for that host's execution run.
        """
        kw = kw.get("kw")
        cmd = self.base_cmd + " show" + core_utils.build_cmd_args(kw=kw)
        logger.info(f"Running command {cmd}")
        return fabfile.run_command(cmd, config=kw.get("env_config"))

    def rm(self, **kw):
        """
        Remove log object.

        Args:
            object(str): name of the object

        Returns:
            Dict(str)
            A mapping of host strings to the given task's return value for that host's execution run.
        """
        kw = kw.get("kw")
        object_name = kw.get("object")
        cmd = self.base_cmd + f" rm --object={object_name}"
        logger.info(f"Running command {cmd}")
        return fabfile.run_command(cmd, config=kw.get("env_config"))



import logging

import src.RhcsQeSdk.core.cli.fabfile as fabfile
from src.RhcsQeSdk.core.utilities import core_utils

logger = logging.getLogger(__name__)
logger.setLevel(logging.DEBUG)

formatter = logging.Formatter(
    "%(asctime)s - %(levelname)s - %(name)s:%(lineno)d - %(message)s"
)

stream_handler = logging.StreamHandler()
stream_handler.setFormatter(formatter)
stream_handler.setLevel(logging.DEBUG)
logger.addHandler(stream_handler)


class Bucket:
    """This module provides CLI interface to manage bucket operations."""

    def __init__(self, base_cmd):
        self.base_cmd = base_cmd + " bucket"

    def list_(self, **kw):
        """List buckets, or, if bucket specified with --bucket=<bucket>, list its objects.
        Args:
                kw(dict): Key/value pairs that needs to be provided to the installer
        Example::
        Supported keys:
                bucket(str): takes name of the bucket(optional)
        Returns:
            Dict(str)
            A mapping of host strings to the given task’s return value for that host’s execution run
        """
        kw = kw.get("kw")
        cmd = self.base_cmd + " list" + core_utils.build_cmd_args(kw=kw)
        logger.info(f"Running command {cmd}")
        return fabfile.run_command(cmd, config=kw.get("env_config"))

    def limit_check(self, **kw):
        """Show bucket sharding stats.
        Args:
                kw(dict): Key/value pairs that needs to be provided to the installer
        Example::
        Supported keys:
                warnings-only(bool):  When specified, list only buckets nearing or over
                                                the current max objects per shard value.
        Returns:
            Dict(str)
            A mapping of host strings to the given task’s return value for that host’s execution run
        """
        kw = kw.get("kw")
        cmd = self.base_cmd + " limit check" + core_utils.build_cmd_args(kw=kw)
        logger.info(f"Running command {cmd}")
        return fabfile.run_command(cmd, config=kw.get("env_config"))

    def link(self, **kw):
        """Link bucket to specified user, if --bucket-new-name=<new-name>
        is specified then this command is used for renaming the bucket.
        Args:
                kw(dict): Key/value pairs that needs to be provided to the installer
        Example::
        Supported keys:
                bucket(str): takes name of the bucket
                bucket-new-name(str): takes new name of bucket(optional)
                uid(str):  takes the user-id
        Returns:
            Dict(str)
            A mapping of host strings to the given task’s return value for that host’s execution run
        """
        kw = kw.get("kw")
        cmd = self.base_cmd + " link" + core_utils.build_cmd_args(kw=kw)
        logger.info(f"Running command {cmd}")
        return fabfile.run_command(cmd, config=kw.get("env_config"))

    def unlink(self, **kw):
        """Unlink bucket from specified user.
        Args:
                kw(dict): Key/value pairs that needs to be provided to the installer
        Example::
        Supported keys:
                bucket(str): takes name of the bucket
                uid(str):  takes the user-id
        Returns:
            Dict(str)
            A mapping of host strings to the given task’s return value for that host’s execution run
        """
        kw = kw.get("kw")

        uid = kw.get("uid")
        bucket_name = kw.get("bucket")
        cmd = self.base_cmd + f" unlink --bucket={bucket_name} --uid={uid}"
        logger.info(f"Running command {cmd}")
        return fabfile.run_command(cmd, config=kw.get("env_config"))

    def chown(self, **kw):
        """Change the ownership of the bucket to the new user.
        Args:
                kw(dict): Key/value pairs that needs to be provided to the installer
        Example::
        Supported keys:
                bucket(str): takes name of the bucket
                uid(str):  takes the user-id
        Returns:
            Dict(str)
            A mapping of host strings to the given task’s return value for that host’s execution run
        """
        kw = kw.get("kw")
        uid = kw.get("uid")
        bucket_name = kw.get("bucket")
        cmd = self.base_cmd + f" chown --bucket={bucket_name} --uid={uid}"
        logger.info(f"Running command {cmd}")
        return fabfile.run_command(cmd, config=kw.get("env_config"))

    def stats(self, **kw):
        """Returns statistics of a specified bucket.
        Args:
                kw(dict): Key/value pairs that needs to be provided to the installer
        Example::
        Supported keys:
                bucket(str): takes name of the bucket
        Returns:
            Dict(str)
            A mapping of host strings to the given task’s return value for that host’s execution run
        """
        kw = kw.get("kw")
        bucket_name = kw.get("bucket")
        cmd = self.base_cmd + f" stats --bucket={bucket_name}"
        logger.info(f"Running command {cmd}")
        return fabfile.run_command(cmd, config=kw.get("env_config"))

    def rm(self, **kw):
        """Remove a specified bucket.
        Args:
                kw(dict): Key/value pairs that needs to be provided to the installer
        Example::
        Supported keys:
                bucket(str): takes name of the bucket
                purge-objects(bool): When specified, the bucket removal will also purge all objects in it.
        Returns:
            Dict(str)
            A mapping of host strings to the given task’s return value for that host’s execution run
        """
        kw = kw.get("kw")
        cmd = self.base_cmd + " rm" + core_utils.build_cmd_args(kw=kw)
        logger.info(f"Running command {cmd}")
        return fabfile.run_command(cmd, config=kw.get("env_config"))

    def check(self, **kw):
        """Check bucket index.
        Args:
                kw(dict): Key/value pairs that needs to be provided to the installer
        Example::
        Supported keys:
                check-objects(bool): Rebuilds bucket index according to actual objects state.
        Returns:
            Dict(str)
            A mapping of host strings to the given task’s return value for that host’s execution run
        """
        kw = kw.get("kw")
        cmd = self.base_cmd + " check" + core_utils.build_cmd_args(kw=kw)
        logger.info(f"Running command {cmd}")
        return fabfile.run_command(cmd, config=kw.get("env_config"))

    def rewrite(self, **kw):
        """Rewrite all objects in the specified bucket.
        Args:
                kw(dict): Key/value pairs that needs to be provided to the installer
        Example::
        Supported keys:
                bucket(str): takes name of the bucket
        Returns:
            Dict(str)
            A mapping of host strings to the given task’s return value for that host’s execution run
        """
        kw = kw.get("kw")
        bucket_name = kw.get("bucket")
        cmd = self.base_cmd + f" rewrite --bucket={bucket_name}"
        logger.info(f"Running command {cmd}")
        return fabfile.run_command(cmd, config=kw.get("env_config"))

    def radoslist(self, **kw):
        """List the rados objects that contain the data for all objects
        is the designated bucket, if –bucket=<bucket> is specified,
        or otherwise all buckets.
        Args:
                kw(dict): Key/value pairs that needs to be provided to the installer
        Example::
        Supported keys:
                bucket(str): takes name of the bucket(optional)
        Returns:
            Dict(str)
            A mapping of host strings to the given task’s return value for that host’s execution run
        """
        kw = kw.get("kw")
        cmd = self.base_cmd + " radoslist" + core_utils.build_cmd_args(kw=kw)
        logger.info(f"Running command {cmd}")
        return fabfile.run_command(cmd, config=kw.get("env_config"))

    def reshard(self, **kw):
        """Reshard a bucket.
        Args:
                kw(dict): Key/value pairs that needs to be provided to the installer
        Example::
        Supported keys:
                bucket(str): takes name of the bucket(optional)
                num-shards(int):  takes no. of shards
        Returns:
            Dict(str)
            A mapping of host strings to the given task’s return value for that host’s execution run
        """
        kw = kw.get("kw")
        num_shard = kw.get("num-shards")
        bucket_name = kw.get("bucket")
        cmd = (
            self.base_cmd + f" reshard --bucket={bucket_name} --num-shards={num_shard}"
        )
        logger.info(f"Running command {cmd}")
        return fabfile.run_command(cmd, config=kw.get("env_config"))

    def sync_enable(self, **kw):
        """Enable bucket sync.
        Args:
                kw(dict): Key/value pairs that needs to be provided to the installer
        Example::
        Supported keys:
                bucket(str): takes name of the bucket
        Returns:
            Dict(str)
            A mapping of host strings to the given task’s return value for that host’s execution run
        """
        kw = kw.get("kw")
        bucket_name = kw.get("bucket")
        cmd = self.base_cmd + f" sync enable --bucket={bucket_name}"
        logger.info(f"Running command {cmd}")
        return fabfile.run_command(cmd, config=kw.get("env_config"))

    def sync_disable(self, **kw):
        """Disable bucket sync.
        Args:
                kw(dict): Key/value pairs that needs to be provided to the installer
        Example::
        Supported keys:
                bucket(str): takes name of the bucket
        Returns:
            Dict(str)
            A mapping of host strings to the given task’s return value for that host’s execution run
        """
        kw = kw.get("kw")
        bucket_name = kw.get("bucket")
        cmd = self.base_cmd + f" sync disable --bucket={bucket_name}"
        logger.info(f"Running command {cmd}")
        return fabfile.run_command(cmd, config=kw.get("env_config"))



import logging
from copy import deepcopy

import src.RhcsQeSdk.core.cli.fabfile as fabfile
from src.RhcsQeSdk.core.utilities import core_utils

logger = logging.getLogger(__name__)
logger.setLevel(logging.DEBUG)

formatter = logging.Formatter(
    "%(asctime)s - %(levelname)s - %(name)s:%(lineno)d - %(message)s"
)

stream_handler = logging.StreamHandler()
stream_handler.setFormatter(formatter)
stream_handler.setLevel(logging.DEBUG)
logger.addHandler(stream_handler)


class Zonegroup:
    """
    This module provides CLI interface for zone-group management of the object gateway service.
    """

    def __init__(self, base_cmd):
        self.base_cmd = base_cmd + " zonegroup"

    def create(self, **kw):
        """
        To create a zonegroup, specify a zonegroup name.
        Args:
          kw (Dict): Key/value pairs that needs to be provided to the installer.
        Example:
          Supported keys:
            rgw-zonegroup(str) : Takes the zone group name as an input.
            default(bool) : True to create default zone , False for non-default zone.
            rgw-realm(str): Takes the realm name as input.

        Returns:
          Dict(str)
            A mapping of host strings to the given task’s return value for that host’s execution run
        """
        kw = kw.get("kw")
        kw_copy = deepcopy(kw)
        zonegroup_name = kw_copy.pop("rgw-zonegroup", "")
        cmd_args = core_utils.build_cmd_args(kw=kw_copy)
        cmd = self.base_cmd + f" create --rgw-zonegroup={zonegroup_name}" + cmd_args
        logger.info(f"Running command {cmd}")
        return fabfile.run_command(cmd, config=kw.get("env_config"))

    def add_(self, **kw):
        """
        To add a zone, specify a zone name and the zonegroup name under which zone must be added.
        Args:
          kw (Dict): Key/value pairs that needs to be provided to the installer.
        Example:
          Supported keys:
            rgw-zonegroup(str) : Takes the zone group name as an input.
            rgw-zone(str) : Takes the zone name as an input.

        Returns:
          Dict(str)
            A mapping of host strings to the given task’s return value for that host’s execution run
        """
        kw = kw.get("kw")
        zonegroup_name = kw.get("rgw-zonegroup")
        zone_name = kw.get("rgw-zone")
        cmd = (
            self.base_cmd
            + f" add --rgw-zonegroup={zonegroup_name} --rgw-zone={zone_name}"
        )
        logger.info(f"Running command {cmd}")
        return fabfile.run_command(cmd, config=kw.get("env_config"))

    def default(self, **kw):
        """
        To make a zone group as a default one specify the zonegroup name.
        Args:
          kw (Dict): Key/value pairs that needs to be provided to the installer.
        Example:
          Supported keys:
            rgw-zonegroup(str) : Takes the zone group name as an input.

        Returns:
          Dict(str)
            A mapping of host strings to the given task’s return value for that host’s execution run
        """
        kw = kw.get("kw")
        zonegroup_name = kw.get("rgw-zonegroup")
        cmd = self.base_cmd + f" default --rgw-zonegroup={zonegroup_name}"
        logger.info(f"Running command {cmd}")
        return fabfile.run_command(cmd, config=kw.get("env_config"))

    def get_(self, **kw):
        """
        To get a zonegroup info, specify a zonegroup name.
        Args:
          kw (Dict): Key/value pairs that needs to be provided to the installer.
        Example:
          Supported keys:
            rgw-zonegroup(str) : Takes the zone group name as an input.

        Returns:
          Dict(str)
            A mapping of host strings to the given task’s return value for that host’s execution run
        """
        kw = kw.get("kw")
        zonegroup_name = kw.get("rgw-zonegroup")
        cmd = self.base_cmd + f" get --rgw-zonegroup={zonegroup_name}"
        logger.info(f"Running command {cmd}")
        return fabfile.run_command(cmd, config=kw.get("env_config"))

    def rename(self, **kw):
        """
        To rename a zonegroup, specify a new zonegroup name.
        Args:
          kw (Dict): Key/value pairs that needs to be provided to the installer.
        Example:
          Supported keys:
            rgw-zonegroup(str) : Takes the zonegroup name as an input.
            zonegroup-new-name(str) : Takes the new zonegroup name as an input.

        Returns:
          Dict(str)
            A mapping of host strings to the given task’s return value for that host’s execution run
        """
        kw = kw.get("kw")
        zonegroup_name = kw.get("rgw-zonegroup")
        new_zonegroup_name = kw.get("zonegroup-new-name")
        cmd = (
            self.base_cmd
            + f" rename --rgw-zonegroup={zonegroup_name} --zonegroup-new-name={new_zonegroup_name}"
        )
        logger.info(f"Running command {cmd}")
        return fabfile.run_command(cmd, config=kw.get("env_config"))

    def set_(self, **kw):
        """
        Defining a zone group consists of creating a JSON object.
        specifying at least the required settings name, api_name, is_master:
        Note: You can only have one master zone group.
        Args:
          kw (Dict): Key/value pairs that needs to be provided to the installer.
        Example:
          Supported keys:
            infile(str) : Takes the Json file you created as an input.

        Returns:
          Dict(str)
            A mapping of host strings to the given task’s return value for that host’s execution run
        """
        kw = kw.get("kw")
        infile = kw.get("infile")
        cmd = self.base_cmd + f" set --infile={infile}"
        logger.info(f"Running command {cmd}")
        return fabfile.run_command(cmd, config=kw.get("env_config"))

    def delete(self, **kw):
        """
        To remove a zonegroup, specify a zonegroup name.
        Args:
          kw (Dict): Key/value pairs that needs to be provided to the installer.
        Example:
          Supported keys:
            rgw-zonegroup(str) : Takes the zone group name as an input.

        Returns:
          Dict(str)
            A mapping of host strings to the given task’s return value for that host’s execution run
        """
        kw = kw.get("kw")
        zonegroup_name = kw.get("rgw-zonegroup")
        cmd = self.base_cmd + f" delete --rgw-zonegroup={zonegroup_name}"
        logger.info(f"Running command {cmd}")
        return fabfile.run_command(cmd, config=kw.get("env_config"))

    def remove_(self, **kw):
        """
        This method is used to remove a zone from a zonegroup.
        Args:
          kw (Dict): Key/value pairs that needs to be provided to the installer.
        Example:
          Supported keys:
            rgw-zonegroup(str) : Takes the zone group name as an input.
            rgw-zone(str) : Takes the zone name as an input.

        Returns:
          Dict(str)
            A mapping of host strings to the given task’s return value for that host’s execution run.
        """
        kw = kw.get("kw")
        zonegroup_name = kw.get("rgw-zonegroup")
        rgw_zone = kw.get("rgw-zone")
        cmd = (
            self.base_cmd
            + f" remove --rgw-zonegroup={zonegroup_name} --rgw-zone={rgw_zone}"
        )
        logger.info(f"Running command {cmd}")
        return fabfile.run_command(cmd, config=kw.get("env_config"))

    def modify(self, **kw):
        """
        This method is used to modify an existing zone group’s settings.
        Args:
          kw (Dict): Key/value pairs that needs to be provided to the installer.
        Example:
          Supported keys:
            rgw-zonegroup(str) : Takes the zone group name as an input.
            master(bool): True to create default zone, False for non-default zonegroup.

        Returns:
          Dict(str)
            A mapping of host strings to the given task’s return value for that host’s execution run
        """
        kw = kw.get("kw")
        zonegroup_name = kw.get("rgw-zonegroup")
        master = kw.get("master")
        if master:
            cmd = self.base_cmd + f" modify --rgw-zonegroup={zonegroup_name} --master"
        else:
            cmd = self.base_cmd + f" modify --rgw-zonegroup={zonegroup_name}"
        logger.info(f"Running command {cmd}")
        return fabfile.run_command(cmd, config=kw.get("env_config"))

    def list_(self, **kw):
        """
        A Ceph cluster contains a list of zone groups. To list the zone groups.
        Args:
          None

        Returns:
          Dict(str)
            A mapping of host strings to the given task’s return value for that host’s execution run
        """
        kw = kw.get("kw")
        cmd = self.base_cmd + " list"
        logger.info(f"Running command {cmd}")
        return fabfile.run_command(cmd, config=kw.get("env_config"))

    def placement_add(self, **kw):
        """
        This method is used to add a placement target id to a zonegroup.
        Args:
          kw (Dict): Key/value pairs that needs to be provided to the installer.
        Example:
          Supported keys:
            rgw-zonegroup(str) : Takes the zone group name as an input.
            placement-id(str): Takes a placement name as an input.

        Returns:
          Dict(str)
            A mapping of host strings to the given task’s return value for that host’s execution run
        """
        kw = kw.get("kw")
        zonegroup_name = kw.get("rgw-zonegroup")
        placement_id = kw.get("placement-id")
        cmd = (
            self.base_cmd
            + f" placement add --rgw-zonegroup {zonegroup_name} --placement-id {placement_id}"
        )
        logger.info(f"Running command {cmd}")
        return fabfile.run_command(cmd, config=kw.get("env_config"))

    def placement_list(self, **kw):
        """
        This method will list placement targets.
        Args:
          None

        Returns:
          Dict(str)
            A mapping of host strings to the given task’s return value for that host’s execution run
        """
        kw = kw.get("kw")
        cmd = self.base_cmd + " placement list"
        logger.info(f"Running command {cmd}")
        return fabfile.run_command(cmd, config=kw.get("env_config"))

    def placement_modify(self, **kw):
        """
        This method will list placement target's settings.
        Args:
          kw (Dict): Key/value pairs that needs to be provided to the installer.
        Example:
          Supported keys:
            tags(list):The list of tags for zonegroup placement modify command.
            tags-add(list):The list of tags to add for zonegroup placement modify command.
            tags-rm(list): The list of tags to remove for zonegroup placement modify command.

        Returns:
          Dict(str)
            A mapping of host strings to the given task’s return value for that host’s execution run
        """
        kw = kw.get("kw")
        tags = kw.get("tags")
        tags_add = kw.get("tags-add")
        tags_rm = kw.get("tags-rm")
        cmd = (
            self.base_cmd
            + f" placement modify --tags={tags} --tags-add={tags_add} --tags-rm={tags_rm}"
        )
        logger.info(f"Running command {cmd}")
        return fabfile.run_command(cmd, config=kw.get("env_config"))

    def placement_default(self, **kw):
        """
        This method is used to set a zonegroup’s default placement target.
        Args:
          kw (Dict): Key/value pairs that needs to be provided to the installer.
        Example:
          Supported keys:
            rgw-zonegroup(str) : Takes the zone group name as an input.
            placement-id(str): Takes a placement name as an input.

        Returns:
          Dict(str)
            A mapping of host strings to the given task’s return value for that host’s execution run
        """
        kw = kw.get("kw")
        zonegroup_name = kw.get("rgw-zonegroup")
        placement_id = kw.get("placement-id")
        cmd = (
            self.base_cmd
            + f" placement default --rgw-zonegroup {zonegroup_name} --placement-id {placement_id}"
        )
        logger.info(f"Running command {cmd}")
        return fabfile.run_command(cmd, config=kw.get("env_config"))



import logging

import src.RhcsQeSdk.core.cli.fabfile as fabfile
from src.RhcsQeSdk.core.cli.ceph.rule import Rule

logger = logging.getLogger(__name__)
logger.setLevel(logging.DEBUG)

formatter = logging.Formatter(
    "%(asctime)s - %(levelname)s - %(name)s:%(lineno)d - %(message)s"
)

stream_handler = logging.StreamHandler()
stream_handler.setFormatter(formatter)
stream_handler.setLevel(logging.DEBUG)
logger.addHandler(stream_handler)


class Crush:
    """The module provides CLI interface to implement CRUSH commands that determine
    how to store and retrieve data."""

    def __init__(self, base_cmd):
        self.base_cmd = base_cmd + " crush"
        self.rule = Rule(self.base_cmd)

    def add_(self, **kw):
        """
        The command add will add or update a crushmap position
        for an osd with a particular weight in a specific location.

        Args:
            kw(Dict): Key/value pairs that needs to be provided to the installer.
            Example::
            Supported Keys:

            osd_name(str): name of the osd.
            crush_weight(double): crush weight for osd.
            bucket_type(str): type of the bucket.

        Returns:
            Dict(str)
            A mapping of host strings of the given task's return value for that host's execution run.
        """
        kw = kw.get("kw")
        osd_name = kw.get("osd_name", "")
        crush_weight = kw.get("crush_weight", 0.0)
        bucket_type = kw.get("bucket_type", "")
        cmd = self.base_cmd + f" add {osd_name} {crush_weight} {bucket_type}"
        logger.info(f"Running command {cmd}")
        return fabfile.run_command(cmd, config=kw.get("env_config"))

    def add_bucket(self, **kw):
        """
        A bucket is a node/location of physical hardware.
        The command add-bucket will add a bucket instance to the CRUSH hierarchy.

        Args:
            kw(Dict): Key/value pairs that needs to be provided to the installer.
            Example::
            Supported Keys:

            bucket_name(str): name of the bucket.
            bucket_type(str): type of the bucket.

        Returns:
            Dict(str)
            A mapping of host strings of the given task's return value for that host's execution run.
        """
        kw = kw.get("kw")
        bucket_name = kw.get("bucket_name", "")
        bucket_type = kw.get("bucket_type", "root")
        cmd = self.base_cmd + f" add-bucket {bucket_name} {bucket_type}"
        logger.info(f"Running command {cmd}")
        return fabfile.run_command(cmd, config=kw.get("env_config"))

    def create_or_move(self, **kw):
        """
        The command create-or-move creates entry or moves entry for an osd with weight to a specified location.

        Args:
            kw(Dict): Key/value pairs that needs to be provided to the installer.
            Example::
            Supported Keys:

            osd_name(str): name of the osd.
            crush_weight(double): crush weight for osd.
            bucket_type(str): type of the bucket.

        Returns:
            Dict(str)
            A mapping of host strings of the given task's return value for that host's execution run.
        """
        kw = kw.get("kw")
        osd_name = kw.get("osd_name", "")
        crush_weight = kw.get("crush_weight", 0.0)
        bucket_type = kw.get("bucket_type", "")
        cmd = self.base_cmd + f" create-or-move {osd_name} {crush_weight} {bucket_type}"
        logger.info(f"Running command {cmd}")
        return fabfile.run_command(cmd, config=kw.get("env_config"))

    def dump(self, **kw):
        """
        The command dump will dump a crush map.

        Args:
            kw(Dict): Key/value pairs that needs to be provided to the installer.
            Example::
            Supported Keys:

            None

        Returns:
            Dict(str)
            A mapping of host strings of the given task's return value for that host's execution run.
        """
        kw = kw.get("kw")
        cmd = self.base_cmd + " dump"
        logger.info(f"Running command {cmd}")
        return fabfile.run_command(cmd, config=kw.get("env_config"))

    def get_tunable(self, **kw):
        """
        The command get-tunable will retrieve the get-tunable straw_calc_version.

        Args:
            kw(Dict): Key/value pairs that needs to be provided to the installer.
            Example::
            Supported Keys:

            None

        Returns:
            Dict(str)
            A mapping of host strings of the given task's return value for that host's execution run.
        """
        kw = kw.get("kw")
        cmd = self.base_cmd + " get-tunable straw_calc_version"
        logger.info(f"Running command {cmd}")
        return fabfile.run_command(cmd, config=kw.get("env_config"))

    def link(self, **kw):
        """
        The command link will link existing entry for a node under a location.

        Args:
            kw(Dict): Key/value pairs that needs to be provided to the installer.
            Example::
            Supported Keys:

            node_name(str): name of the node.
            bucket_type(str): type of the bucket.

        Returns:
            Dict(str)
            A mapping of host strings of the given task's return value for that host's execution run.
        """
        kw = kw.get("kw")
        node_name = kw.get("node_name", "")
        bucket_type = kw.get("bucket_type", "")
        cmd = self.base_cmd + f" link {node_name} {bucket_type}"
        logger.info(f"Running command {cmd}")
        return fabfile.run_command(cmd, config=kw.get("env_config"))

    def move(self, **kw):
        """
        The command move will move existing entry for a node under a location.

        Args:
            kw(Dict): Key/value pairs that needs to be provided to the installer.
            Example::
            Supported Keys:

            osd_name(str): name of the osd.
            bucket_type(str): type of the bucket.

        Returns:
            Dict(str)
            A mapping of host strings of the given task's return value for that host's execution run.
        """
        kw = kw.get("kw")
        osd_name = kw.get("osd_name", "")
        bucket_type = kw.get("bucket_type", "")
        cmd = self.base_cmd + f" move {osd_name} {bucket_type}"
        logger.info(f"Running command {cmd}")
        return fabfile.run_command(cmd, config=kw.get("env_config"))

    def remove_(self, **kw):
        """
        The remove command will remove an osd from the crush map.

        Args:
            kw(Dict): Key/value pairs that needs to be provided to the installer.
            Example::
            Supported Keys:

            osd_name(str): name of the osd.
            ancestor_name(str): name of the ancestor node.

        Returns:
            Dict(str)
            A mapping of host strings of the given task's return value for that host's execution run.
        """
        kw = kw.get("kw")
        osd_name = kw.get("osd_name", "")
        ancestor_name = kw.get("ancestor_name", "")
        cmd = self.base_cmd + f" remove {osd_name} {ancestor_name}"
        logger.info(f"Running command {cmd}")
        return fabfile.run_command(cmd, config=kw.get("env_config"))

    def rename_bucket(self, **kw):
        """
        The command rename-bucket will change source name of a bucket to the specified name.

        Args:
            kw(Dict): Key/value pairs that needs to be provided to the installer.
            Example::
            Supported Keys:

            source_name(str): source name of a bucket.
            destination_name(str): destination name of the bucket.

        Returns:
             Dict(str)
             A mapping of host strings of the given task's return value for that host's execution run.
        """
        kw = kw.get("kw")
        source_name = kw.get("source_name", "")
        destination_name = kw.get("destination_name", "")
        cmd = self.base_cmd + f" rename-bucket {source_name} {destination_name}"
        logger.info(f"Running command {cmd}")
        return fabfile.run_command(cmd, config=kw.get("env_config"))

    def reweight(self, **kw):
        """
        The command reweight adjust the osd crush weight in the crush map.

        Args:
            kw(Dict): Key/value pairs that needs to be provided to the installer.
            Example::
            Supported Keys:

            osd_name(str): name of the osd.
            crush_weight(double): crush weight for osd.

        Returns:
            Dict(str)
            A mapping of host strings of the given task's return value for that host's execution run.
        """
        kw = kw.get("kw")
        osd_name = kw.get("osd_name", "")
        crush_weight = kw.get("crush_weight", 0.0)
        cmd = self.base_cmd + f" reweight {osd_name} {crush_weight}"
        logger.info(f"Running command {cmd}")
        return fabfile.run_command(cmd, config=kw.get("env_config"))

    def reweight_all(self, **kw):
        """
        The command reweight-all recalculates weights for the tree to ensure they sum correctly.

        Args:
            kw(Dict): Key/value pairs that needs to be provided to the installer.
            Example::
            Supported Keys:

            None

        Returns:
            Dict(str)
            A mapping of host strings of the given task's return value for that host's execution run.
        """
        kw = kw.get("kw")
        cmd = self.base_cmd + " reweight-all"
        logger.info(f"Running command {cmd}")
        return fabfile.run_command(cmd, config=kw.get("env_config"))

    def reweight_subtree(self, **kw):
        """
        The command reweight-subtree will change all leaf items beneath a node to a weight in a crush map.

        Args:
            kw(Dict): Key/value pairs that needs to be provided to the installer.
            Example::
            Supported Keys:

            osd_name(str): name of the osd.
            crush_weight(double): crush weight for osd leaf items.

        Returns:
            Dict(str)
            A mapping of host strings of the given task's return value for that host's execution run.
        """
        kw = kw.get("kw")
        osd_name = kw.get("osd_name", "")
        crush_weight = kw.get("crush_weight", 0.0)
        cmd = self.base_cmd + f" reweight-subtree {osd_name} {crush_weight}"
        logger.info(f"Running command {cmd}")
        return fabfile.run_command(cmd, config=kw.get("env_config"))

    def set_(self, **kw):
        """
        The command set if used alone will set crush map from input file.
        Else it will update an osd weight in a particular location.

        Args:
            kw(Dict): Key/value pairs that needs to be provided to the installer.
            Example::
            Supported Keys:

            osd_name(str): name of the osd.
            crush_weight(double): crush weight for osd.
            bucket_type(str): type of the bucket.

        Returns:
            Dict(str)
            A mapping of host strings of the given task's return value for that host's execution run.
        """
        kw = kw.get("kw")
        osd_name = kw.get("osd_name", "")
        crush_weight = kw.get("crush_weight", 0.0)
        bucket_type = kw.get("bucket_type", "")
        cmd = self.base_cmd + f" set {osd_name} {crush_weight} {bucket_type}"
        logger.info(f"Running command {cmd}")
        return fabfile.run_command(cmd, config=kw.get("env_config"))

    def set_tunable(self, **kw):
        """
        The command set-tunable will set crush tunable to a value.

        Args:
            kw(Dict): Key/value pairs that needs to be provided to the installer.
            Example::
            Supported Keys:

            value(int): value to be set against the crush tunable.

        Returns:
            Dict(str)
        A mapping of hosts strings to the given task's return value for that host's execution run.
        """
        value = kw.get("value", 0)
        cmd = self.base_cmd + f" set-tunable straw_calc_version {value}"
        logger.info(f"Running command {cmd}")
        return fabfile.run_command(cmd, config=kw.get("env_config"))

    def tunables(self, **kw):
        """
        The command tunables will tune the CRUSH to a known profile.

        Args:
            kw(Dict): Key/value pairs that needs to be provided to the installer.
            Example::
            Supported Keys:

            profile(str): The profile to which the CRUSH is to be tuned.

        Returns:
            Dict(str)
            A mapping of host strings of the given task's return value for that host's execution run.
        """
        kw = kw.get("kw")
        profile = kw.get("profile", "")
        cmd = self.base_cmd + f" tunables {profile}"
        logger.info(f"Running command {cmd}")
        return fabfile.run_command(cmd, config=kw.get("env_config"))

    def show_tunables(self, **kw):
        """
        The command show-tunables will display current crush tunables.

        Args:
            kw(Dict): Key/value pairs that needs to be provided to the installer.
            Example::
            Supported Keys:

            None

        Returns:
            Dict(str)
        A mapping of hosts strings to the given task's return value for that host's execution run.
        """
        kw = kw.get("kw")
        cmd = self.base_cmd + " show-tunables"
        logger.info(f"Running command {cmd}")
        return fabfile.run_command(cmd, config=kw.get("env_config"))

    def unlink(self, **kw):
        """
        The command unlink will unlink a node from a crush map.

        Args:
            kw(Dict): Key/value pairs that needs to be provided to the installer.
            Example::
            Supported Keys:

            osd_name(str): name of the osd.
            ancestor_name(str): name of ancestor node(optional).

        Returns:
            Dict(str)
        A mapping of hosts strings to the given task's return value for that host's execution run.
        """
        kw = kw.get("kw")
        osd_name = kw.get("osd_name", "")
        ancestor_name = kw.get("ancestor_name", "")
        cmd = self.base_cmd + f" unlink {osd_name} {ancestor_name}"
        logger.info(f"Running command {cmd}")
        return fabfile.run_command(cmd, config=kw.get("env_config"))



import logging

from src.RhcsQeSdk.core.utilities.utils import check_and_raise_fabfile_command_failure

logger = logging.getLogger(__name__)
logger.setLevel(logging.INFO)


class ExecuteCommandMixin:
    def __init__(self):
        pass

    def must_pass(self, **kw):
        """
        This method is used to check whether command is successfully executed or not ,else raises an exception.
        Args:
          kw(dict): Key/value pairs that needs to be provided to the installer
          Example:
            Supported keys:
              function(str): Function in which the command needs to be executed.
              kw_args(Dict): arguments sent to the function in the form of dictionary.

        Returns:
          Dict(str)
            A mapping of host strings to the given task’s return value for that host’s execution run
        """
        step_output = kw.get("step_output")
        function = kw.get("function")
        kw_args = kw.get("kw_args", dict())
        kw_args["env_config"] = kw.get("env_config")
        kw_args["cluster_name"] = kw.get("cluster_name")
        logger.info(f"Running function {function}")
        out = function(kw=kw_args)
        if out is None:
            step_output["result"] = None
            step_output["status"] = "pass"
            return None
        step_output["result"] = list(out.values())[0]
        if check_and_raise_fabfile_command_failure(
            output=out, parallel=kw_args["env_config"].get("parallel"), fail=True
        ):
            step_output["status"] = "pass"
        else:
            status = False
            for ip, result in out.items():
                skip_strings = ["already"]
                if result.__dict__.get("failed"):
                    for s in skip_strings:
                        if s in str(result):
                            status = True
                            break
            if status:
                step_output["status"] = "pass"
            else:
                step_output["status"] = "fail"
        logger.info(f"Step output is {step_output}")
        return out

    def must_fail(self, **kw):
        """
        This method is used to check whether command is successfully failed or not ,else raises an exception.
        Args:
          kw(dict): Key/value pairs that needs to be provided to the installer
          Example:
            Supported keys:
              function(str): Function in which the command needs to be executed.
              kw_args(Dict): arguments sent to the function in the form of dictionary.

        Returns:
          Dict(str)
            A mapping of host strings to the given task’s return value for that host’s execution run
        """
        step_output = kw.get("step_output")
        function = kw.get("function")
        kw_args = kw.get("kw_args")
        kw_args["env_config"] = kw.get("env_config")
        kw_args["cluster_name"] = kw.get("cluster_name")
        logger.info(f"Running function {function}")
        out = function(kw=kw_args)
        if out is None:
            step_output["result"] = None
            step_output["status"] = "pass"
            return None
        if check_and_raise_fabfile_command_failure(
            output=out, parallel=kw_args["env_config"].get("parallel"), fail=False
        ):
            step_output["status"] = "pass"
        else:
            step_output["status"] = "fail"
        return out



import logging
from copy import deepcopy

import src.RhcsQeSdk.core.cli.fabfile as fabfile
from src.RhcsQeSdk.core.utilities import core_utils

logger = logging.getLogger(__name__)
logger.setLevel(logging.DEBUG)

formatter = logging.Formatter(
    "%(asctime)s - %(levelname)s - %(name)s:%(lineno)d - %(message)s"
)

stream_handler = logging.StreamHandler()
stream_handler.setFormatter(formatter)
stream_handler.setLevel(logging.DEBUG)
logger.addHandler(stream_handler)


class Client:

    """
    This Class provides wrappers for rbd journal client commands.
    """

    def __init__(self, base_cmd):
        self.base_cmd = base_cmd + " client"

    def disconnect(self, **kw):
        """Wrapper for rbd journal client disconnect.

        Flag image journal client as disconnected.
        Args:
        kw: Key value pair of method arguments
            Example::
            Supported keys:
                journal_spec(str): journal specification.
                                    [<pool-name>/[<namespace>/]]<journal-name>
                namespace(str): name of the namespace
                pool(str): pool name
                image(str): image name
                journal(str): journal name
                client-id(str): client ID (leave unspecified to disconnect all)
        Returns:
            Dict(str):
            A mapping of host strings to the given task's return value for that host's execution run.
        """
        kw = kw.get("kw")

        kw_copy = deepcopy(kw)
        journal_spec = kw_copy.pop("journal_spec", "")
        cmd_args = core_utils.build_cmd_args(kw=kw_copy)

        cmd = f"{self.base_cmd} disconnect {journal_spec}{cmd_args}"
        logger.info(f"Running command {cmd}")
        return fabfile.run_command(cmd, config=kw.get("env_config"))



import logging
from copy import deepcopy

import src.RhcsQeSdk.core.cli.fabfile as fabfile
from src.RhcsQeSdk.core.utilities import core_utils

logger = logging.getLogger(__name__)
logger.setLevel(logging.DEBUG)

formatter = logging.Formatter(
    "%(asctime)s - %(levelname)s - %(name)s:%(lineno)d - %(message)s"
)

stream_handler = logging.StreamHandler()
stream_handler.setFormatter(formatter)
stream_handler.setLevel(logging.DEBUG)
logger.addHandler(stream_handler)


class Lock:
    """
    This Class provides wrappers for rbd lock commands.
    """

    def __init__(self, base_cmd):
        self.base_cmd = base_cmd + " lock"

    def add_(self, kw):
        """
        This method is used to lock an image.
        Args:
          kw(dict): Key/value pairs that needs to be provided to the installer
          Example:
            Supported keys:
                pool_name(str): name of the pool.
                image_name(str): name of the image.
                lockid(str): id of the lock to image.
                image_spec(str): image specification

        Returns:
          Dict(str)
            A mapping of host strings to the given task’s return value for that host’s execution run
        """
        kw = kw.get("kw")
        lockid = kw.get("lockid")
        kw_copy = deepcopy(kw)
        image_spec = kw_copy.pop("image_spec", "")
        cmd_args = core_utils.build_cmd_args(kw=kw_copy)

        cmd = self.base_cmd + " add" + f" {image_spec}{cmd_args} {lockid}"
        logger.info(f"Running command {cmd}")
        return fabfile.run_command(cmd, config=kw.get("env_config"))

    def ls(self, kw):
        """
        This method is used to show locks held on the image.
        Args:
          kw(dict): Key/value pairs that needs to be provided to the installer
          Example:
            Supported keys:
                pool_name(str): name of the pool.
                image_name(str): name of the image.
                image_spec(str): image specification

        Returns:
          Dict(str)
            A mapping of host strings to the given task’s return value for that host’s execution run
        """
        kw = kw.get("kw")
        kw_copy = deepcopy(kw)
        image_spec = kw_copy.pop("image_spec", "")
        cmd_args = core_utils.build_cmd_args(kw=kw_copy)
        cmd = self.base_cmd + " ls" + f" {image_spec}{cmd_args}"
        logger.info(f"Running command {cmd}")
        return fabfile.run_command(cmd, config=kw.get("env_config"))

    def rm(self, kw):
        """Release a lock on an image.
        Args:
          kw(dict): Key/value pairs that needs to be provided to the installer
          Example:
            Supported keys:
                pool_name(str): name of the pool.
                image_name(str): name of the image.
                lock_name(str): name of the lock.
                lockid(str): id of lock.
                image_spec(str): image specification

        Returns:
          Dict(str)
            A mapping of host strings to the given task’s return value for that host’s execution run
        """
        kw = kw.get("kw")
        kw_copy = deepcopy(kw)
        lockid = kw_copy.get("lockid")
        lock_name = kw_copy.get("lock_name")
        image_spec = kw_copy.pop("image_spec", "")
        cmd_args = core_utils.build_cmd_args(kw=kw_copy)
        cmd = self.base_cmd + " rm" + f" {image_spec}{cmd_args} {lockid} {lock_name}"
        logger.info(f"Running command {cmd}")
        return fabfile.run_command(cmd, config=kw.get("env_config"))



import logging

import src.RhcsQeSdk.core.cli.fabfile as fabfile

logger = logging.getLogger(__name__)
logger.setLevel(logging.DEBUG)

formatter = logging.Formatter(
    "%(asctime)s - %(levelname)s - %(name)s:%(lineno)d - %(message)s"
)

stream_handler = logging.StreamHandler()
stream_handler.setFormatter(formatter)
stream_handler.setLevel(logging.DEBUG)
logger.addHandler(stream_handler)


class ConfigKey:
    """
    This module provides CLI interface to implement ceph config-key commands.
    """

    def __init__(self, base_cmd):
        self.base_cmd = base_cmd + " config-key"

    def rm(self, **kw):
        """
        The command rm will remove a configuration key.

        Args:
            kw(Dict): Key/value pairs that needs to be provided to the installer.
            Example::
            Supported Keys:

            key(str): name of the configuration key to be deleted.

        Returns:
            Dict(str)
            A mapping of host strings to the given task's return value for that host's execution run.
        """
        kw = kw.get("kw")
        key = kw.get("key", "")
        cmd = self.base_cmd + f" rm {key}"
        logger.info(f"Running command {cmd}")
        return fabfile.run_command(cmd, config=kw.get("env_config"))

    def ls(self, **kw):
        """
        The command ls will list the configuration keys.

        Args:
            kw(Dict): Key/value pairs that needs to be provided to the installer.
            Example::
            Supported Keys:

            None

        Returns:
            Dict(str)
            A mapping of host strings to the given task's return value for that host's execution run.
        """
        kw = kw.get("kw")
        cmd = self.base_cmd + " ls"
        logger.info(f"Running command {cmd}")
        return fabfile.run_command(cmd, config=kw.get("env_config"))

    def get_(self, **kw):
        """
        The command get will retrieve the value attached to a configuration key.

        Args:
            kw(Dict): Key/value pairs that needs to be provided to the installer.
            Example::
            Supported Keys:

            key(str): name of the key whose value is to be retrieved.

        Returns:
            Dict(str)
            A mapping of host strings to the given task's return value for that host's execution run.
        """
        kw = kw.get("kw")
        key = kw.get("key", "")
        cmd = self.base_cmd + f" get {key}"
        logger.info(f"Running command {cmd}")
        return fabfile.run_command(cmd, config=kw.get("env_config"))

    def set_(self, **kw):
        """
        The command set will set a value against a configuration key.

        Args:
            kw(Dict): Key/value pairs that needs to be provided to the installer.
            Example::
            Supported Keys:

            key(str): name of the configuration key.
            value(int): value to be set against the key.

        Returns:
            Dict(str)
            A mapping of host strings to the given task's return value for that host's execution run.
        """
        kw = kw.get("kw")
        key = kw.get("key", "")
        value = kw.get("value", "")
        cmd = self.base_cmd + f" set {key} {value}"
        logger.info(f"Running command {cmd}")
        return fabfile.run_command(cmd, config=kw.get("env_config"))

    def dump(self, **kw):
        """
        The command dump will dump configuration keys and values.

        Args:
            kw(Dict): Key/value pairs that needs to be provided to the installer.
            Example::
            Supported Keys:

            None

        Returns:
            Dict(str)
            A mapping of host strings to the given task's return value for that host's execution run.
        """
        kw = kw.get("kw")
        cmd = self.base_cmd + " dump"
        logger.info(f"Running command {cmd}")
        return fabfile.run_command(cmd, config=kw.get("env_config"))

    def exists(self, **kw):
        """
        The command exists will check if a configuration key exists or not.

        Args:
            kw(Dict): Key/value pairs that needs to be provided to the installer.
            Example::
            Supported Keys:

            key(str): name of the configuration key.

        Returns:
            Dict(str)
            A mapping of host strings to the given task's return value for that host's execution run.
        """
        kw = kw.get("kw")
        key = kw.get("key", "")
        cmd = self.base_cmd + f" exists {key}"
        logger.info(f"Running command {cmd}")
        return fabfile.run_command(cmd, config=kw.get("env_config"))



import logging

import src.RhcsQeSdk.core.cli.fabfile as fabfile

logger = logging.getLogger(__name__)
logger.setLevel(logging.DEBUG)

formatter = logging.Formatter(
    "%(asctime)s - %(levelname)s - %(name)s:%(lineno)d - %(message)s"
)

stream_handler = logging.StreamHandler()
stream_handler.setFormatter(formatter)
stream_handler.setLevel(logging.DEBUG)
logger.addHandler(stream_handler)


class Blocklist:
    """
    Subcommand blocklist manage blocklisted clients. It uses some additional subcommands.
    """

    def __init__(self, base_cmd):
        self.base_cmd = base_cmd + " blocklist"

    def add_(self, **kw):
        """
        Subcommand add adds <addr> to blocklist (optionally until <expire> seconds from now)

        Args:
            kw(Dict): Key/value pairs that needs to be provided to the installer.
            Example::
            Supported Keys:
                add:
                  entity_addr(str) : address of the entity
                  expiry(float) : expiry seconds from now(optional)

        Returns:
            Dict(str)
            A mapping of host strings to the given task's return value for that host's execution run.
        """
        kw = kw.get("kw")
        entity_addr = kw.get("entity_addr")
        expiry = kw.get("expiry")
        cmd = f"{self.base_cmd} add {entity_addr}"
        if expiry:
            cmd = cmd + f" {expiry}"
        logger.info(f"Running command {cmd}")
        return fabfile.run_command(cmd, config=kw.get("env_config"))

    def ls(self, **kw):
        """
        Subcommand ls show blocklisted clients

        Args:
            None

        Returns:
            Dict(str)
            A mapping of host strings to the given task's return value for that host's execution run.
        """
        kw = kw.get("kw")
        cmd = f"{self.base_cmd} ls"
        logger.info(f"Running command {cmd}")
        return fabfile.run_command(cmd, config=kw.get("env_config"))

    def rm(self, **kw):
        """
        Subcommand rm remove <addr> from blocklist

        Args:
            kw(Dict): Key/value pairs that needs to be provided to the installer.
            Example::
            Supported Keys:
                add:
                  entity_addr(str) : address of the entity

        Returns:
            Dict(str)
            A mapping of host strings to the given task's return value for that host's execution run.
        """
        kw = kw.get("kw")
        entity_addr = kw.get("entity_addr")
        cmd = f"{self.base_cmd} rm {entity_addr}"
        logger.info(f"Running command {cmd}")
        return fabfile.run_command(cmd, config=kw.get("env_config"))



import logging

import src.RhcsQeSdk.core.cli.fabfile as fabfile
from src.RhcsQeSdk.core.utilities import core_utils

logger = logging.getLogger(__name__)
logger.setLevel(logging.DEBUG)

formatter = logging.Formatter(
    "%(asctime)s - %(levelname)s - %(name)s:%(lineno)d - %(message)s"
)

stream_handler = logging.StreamHandler()
stream_handler.setFormatter(formatter)
stream_handler.setLevel(logging.DEBUG)
logger.addHandler(stream_handler)


class Pg:
    """
    This module provides CLI iderface used for managing the placement groups in OSDs.
    """

    def __init__(self, base_cmd):
        self.base_cmd = base_cmd + " pg"

    def dump(self, **kw):
        """Inerface to get the statistics for the placement groups in your cluster.
        Args:
                kw(dict): Key/value pairs that needs to be provided to the installer
        Example::
        Supported keys:
                format(str): Valid formats are plain and json (optional)
        Returns:
            Dict(str)
            A mapping of host strings of the given task's return value for that host's execution run.
        """
        kw = kw.get("kw")
        cmd = self.base_cmd + " dump" + core_utils.build_cmd_args(kw=kw)
        logger.info(f"Running commmand {cmd}")
        return fabfile.run_command(cmd, config=kw.get("env_config"))

    def map_(self, **kw):
        """To get the placement group map for a particular placement group.
        Args:
                kw(dict): Key/value pairs that needs to be provided to the installer
        Example::
        Supported keys:
                pg_id(str): id of the placement group
        Returns:
            Dict(str)
            A mapping of host strings of the given task's return value for that host's execution run.
        """
        kw = kw.get("kw")
        pg_id = kw.get("pg_id", "")
        cmd = self.base_cmd + " map" + f" {pg_id}"
        logger.info(f"Running commmand {cmd}")
        return fabfile.run_command(cmd, config=kw.get("env_config"))

    def scrub(self, **kw):
        """To scrub a placement group, execute the following.
        Args:
                kw(dict): Key/value pairs that needs to be provided to the installer
        Example::
        Supported keys:
                pg_id(str): id of the placement group
        Returns:
            Dict(str)
            A mapping of host strings of the given task's return value for that host's execution run.
        """
        kw = kw.get("kw")
        pg_id = kw.get("pg_id", "")
        cmd = self.base_cmd + " scrub" + f" {pg_id}"
        logger.info(f"Running commmand {cmd}")
        return fabfile.run_command(cmd, config=kw.get("env_config"))

    def debug(self, **kw):
        """Subcommand debug shows debug info about pgs.
        Args:
                kw(dict): Key/value pairs that needs to be provided to the installer
        Example::
        Supported keys:
                option(str): unfound_objects_exist|degraded_pgs_exist
        Returns:
            Dict(str)
            A mapping of host strings of the given task's return value for that host's execution run.
        """
        kw = kw.get("kw")
        option = kw.get("option", "")
        cmd = self.base_cmd + " debug" + f"{option}"
        logger.info(f"Running commmand {cmd}")
        return fabfile.run_command(cmd, config=kw.get("env_config"))

    def deep_scrub(self, **kw):
        """Subcommand deep-scrub starts deep-scrub on <pgid>.
        Args:
                kw(dict): Key/value pairs that needs to be provided to the installer
        Example::
        Supported keys:
                pg_id(str): id of the placement group
        Returns:
            Dict(str)
            A mapping of host strings of the given task's return value for that host's execution run.
        """
        kw = kw.get("kw")
        pgid = kw.get("pgid", "")
        cmd = self.base_cmd + " deep-scrub" + f" {pgid}"
        logger.info(f"Running commmand {cmd}")
        return fabfile.run_command(cmd, config=kw.get("env_config"))

    def dump_pools_json(self, **kw):
        """Subcommand dump_pools_json shows pg pools info in json only.
        Args:
                None
        Returns:
            Dict(str)
            A mapping of host strings of the given task's return value for that host's execution run.
        """
        kw = kw.get("kw")
        cmd = self.base_cmd + " dump_pools_json"
        logger.info(f"Running commmand {cmd}")
        return fabfile.run_command(cmd, config=kw.get("env_config"))

    def getmap(self, **kw):
        """Subcommand getmap gets binary pg map to -o/stdout.
        Args:
                None
        Returns:
            Dict(str)
            A mapping of host strings of the given task's return value for that host's execution run.
        """
        kw = kw.get("kw")
        cmd = self.base_cmd + " getmap"
        logger.info(f"Running commmand {cmd}")
        return fabfile.run_command(cmd, config=kw.get("env_config"))

    def repair(self, **kw):
        """Subcommand repair starts repair on <pgid>.
        Args:
                kw(dict): Key/value pairs that needs to be provided to the installer
        Example::
        Supported keys:
                pg_id(str): id of the placement group
        Returns:
            Dict(str)
            A mapping of host strings of the given task's return value for that host's execution run.
        """
        kw = kw.get("kw")
        pgid = kw.get("pgid", "")
        cmd = self.base_cmd + " repair" + f" {pgid}"
        logger.info(f"Running commmand {cmd}")
        return fabfile.run_command(cmd, config=kw.get("env_config"))

    def stat(self, **kw):
        """Subcommand stat shows placement group status.
        Args:
                None
        Returns:
            Dict(str)
            A mapping of host strings of the given task's return value for that host's execution run.
        """
        kw = kw.get("kw")
        cmd = self.base_cmd + " stat"
        logger.info(f"Running commmand {cmd}")
        return fabfile.run_command(cmd, config=kw.get("env_config"))

    def dump_json(self, **kw):
        """Subcommand dump_json shows human-readable version of pg map in json only.
        Args:
                kw(dict): Key/value pairs that needs to be provided to the installer
        Example::
        Supported keys:
                option(str): all|summary|sum|delta|pools|osds|pgs|pgs_brief
        Returns:
            Dict(str)
            A mapping of host strings of the given task's return value for that host's execution run.
        """
        kw = kw.get("kw")
        option = kw.get("option", "")
        cmd = self.base_cmd + " dump_json" + f" {option}"
        logger.info(f"Running commmand {cmd}")
        return fabfile.run_command(cmd, config=kw.get("env_config"))

    def dump_stuck(self, **kw):
        """Subcommand dump_stuck shows information about stuck pgs.
        Args:
                kw(dict): Key/value pairs that needs to be provided to the installer
        Example::
        Supported keys:
                option(str): inactive|unclean|stale|undersized|degraded
                id(int): id of the placement group
        Returns:
            Dict(str)
            A mapping of host strings of the given task's return value for that host's execution run.
        """
        kw = kw.get("kw")
        option = kw.get("option", "")
        id = kw.get("id", "")
        cmd = self.base_cmd + " dump_stuck" + f" {option} {id}"
        logger.info(f"Running commmand {cmd}")
        return fabfile.run_command(cmd, config=kw.get("env_config"))

    def ls(self, **kw):
        """Subcommand ls lists pg with specific pool, osd, state.
        Args:
                kw(dict): Key/value pairs that needs to be provided to the installer
        Example::
        Supported keys:
                pg_state(str): state of placement group
                id|osd.id(str): id of the osd
        Returns:
            Dict(str)
            A mapping of host strings of the given task's return value for that host's execution run.
        """
        kw = kw.get("kw")
        pg_state = kw.get("pg-state", "")
        id = kw.get("id", "")
        cmd = self.base_cmd + " ls" + f" {id} {pg_state}"
        logger.info(f"Running commmand {cmd}")
        return fabfile.run_command(cmd, config=kw.get("env_config"))

    def ls_by_osd(self, **kw):
        """Subcommand ls-by-osd lists pg on osd [osd].
        Args:
                kw(dict): Key/value pairs that needs to be provided to the installer
        Example::
        Supported keys:
                osdname(str): name of the osd
                id|osd.id(str): id of the osd
                pg_state(str): state of the placement group
        Returns:
            Dict(str)
            A mapping of host strings of the given task's return value for that host's execution run.
        """
        kw = kw.get("kw")
        osdname = kw.get("osdname", "")
        id = kw.get("id", "")
        pg_state = kw.get("pg-state", "")
        cmd = self.base_cmd + " ls-by-osd" + f" {osdname} {id} {pg_state}"
        logger.info(f"Running commmand {cmd}")
        return fabfile.run_command(cmd, config=kw.get("env_config"))

    def ls_by_pool(self, **kw):
        """Subcommand ls-by-pool lists pg with pool = [poolname].
        Args:
                kw(dict): Key/value pairs that needs to be provided to the installer
        Example::
        Supported keys:
                poolstr(str): name of the pool
                id(str): id of the placement group
                pg_state(str): state of the placement group
        Returns:
            Dict(str)
            A mapping of host strings of the given task's return value for that host's execution run.
        """
        kw = kw.get("kw")
        pg_state = kw.get("pg-state", "")
        poolstr = kw.get("poolstr", "")
        id = kw.get("id", "")
        cmd = self.base_cmd + " ls-by-pool" + f" {poolstr} {id} {pg_state}"
        logger.info(f"Running commmand {cmd}")
        return fabfile.run_command(cmd, config=kw.get("env_config"))

    def ls_by_primary(self, **kw):
        """Subcommand ls-by-primary lists pg with primary = [osd].
        Args:
                kw(dict): Key/value pairs that needs to be provided to the installer
        Example::
        Supported keys:
                osdname(str): name of the osd
                id|osd.id(str): id of the osd
                pg_state(str): state of the placement group
        Returns:
            Dict(str)
            A mapping of host strings of the given task's return value for that host's execution run.
        """
        kw = kw.get("kw")
        osdname = kw.get("osdname", "")
        id = kw.get("id", "")
        pg_state = kw.get("pg-state", "")
        cmd = self.base_cmd + " ls-by-primary" + f" {osdname} {id} {pg_state}"
        logger.info(f"Running commmand {cmd}")
        return fabfile.run_command(cmd, config=kw.get("env_config"))



"""Contains utils required for sdk layer.

Methods in this module to be used for sdk layer only.
"""
import logging
from copy import deepcopy

from src.RhcsQeSdk.core.cli import fabfile
from src.RhcsQeSdk.core.utilities.metadata import Metadata

logger = logging.getLogger(__name__)
logger.setLevel(logging.INFO)

formatter = logging.Formatter(
    "%(asctime)s - %(levelname)s - %(name)s:%(lineno)d - %(message)s"
)

stream_handler = logging.StreamHandler()
stream_handler.setFormatter(formatter)

logger.addHandler(stream_handler)


def build_cmd_args(seperator=None, **kw):
    """This method checks from the dictionary the optional arguments
    if present it adds them in "cmd" and returns cmd.
    Args:
        kw(dict) -> Takes a dictionary as an input.
        seperator(bool) -> True if key and value needs to be separated with an =.
    Returns:
        cmd(str): Returns a command string.

    eg:
        Args:
            seperator: None
            kw={"uid":"<uid>", "purge-keys": True, "purge-data":True}
        Returns:
            " --uid <uid> --purge-keys --purge-data"
    """
    kw = kw.get("kw")
    cmd = ""
    if kw is None:
        return ""
    for k, v in kw.items():
        if kw[k] and str(k) != "env_config" and str(k) != "cluster_name":
            if v is True:
                cmd = cmd + f" --{k}"
            else:
                if not seperator:
                    cmd = cmd + f" --{k} {v}"
                else:
                    cmd = cmd + f" --{k}={v}"
    return cmd


def parse_host_name(host_name, cluster_name):
    """
    This method parses hostname based on clustername.
    Args:
        hostname(str) -> name of node.
        cluster_name(str) -> name of cluster.
    Returns:
        hosts(list): Returns a list of node names.
    """
    ceph = Metadata().__dict__.get("ceph")
    if host_name == "all":
        return ceph.ceph_node.get_vm_nodes(cluster_name)
    else:
        nodes_list = ceph.ceph_role.get_nodenames_by_role(host_name, cluster_name)
        return " ".join(nodes_list)


def copy_admin_sshkeys(**kw):
    """
    This method distributes cephadm public keys to other nodes.
    Args:
        kw(dict) -> Takes a dictionary as an input.
    Returns:
        Dict(str)
        A mapping of host strings of the given task's return value for that host's execution run.
    """
    kw = kw.get("kw")
    env_config_copy = deepcopy(kw.get("env_config"))
    env_config_copy["username"] = "root"
    env_config_copy["password"] = "passwd"
    ceph_cluster_dict = kw.get("ceph_cluster_dict")
    cluster_name = kw.get("cluster_name")
    ips = []
    nodes = ceph_cluster_dict[cluster_name].get_nodes("_admin")
    for node in nodes:
        ips.append(node.ip_address)
    env_config_copy["hosts"] = ips
    out = fabfile.run_command("cat /etc/ceph/ceph.pub", env_config_copy)
    out = list(out.values())[0]
    ceph_pub_key = f"\n{out}"
    for ip in ips:
        env_config_copy["hosts"] = ip
        fabfile.run_command(
            f"echo -e '{ceph_pub_key}' >> .ssh/authorized_keys", env_config_copy
        )
    nodes = ceph_cluster_dict[cluster_name].get_nodes()
    for i in range(len(nodes)):
        env_config_copy["hosts"] = nodes[i].ip_address
        logger.info("Updating fqdnhostnames to shortnames")
        fabfile.run_command(f"hostname {nodes[i].hostname}", env_config_copy)



import logging

import src.RhcsQeSdk.core.cli.fabfile as fabfile

logger = logging.getLogger(__name__)
logger.setLevel(logging.DEBUG)

formatter = logging.Formatter(
    "%(asctime)s - %(levelname)s - %(name)s:%(lineno)d - %(message)s"
)

stream_handler = logging.StreamHandler()
stream_handler.setFormatter(formatter)
stream_handler.setLevel(logging.DEBUG)
logger.addHandler(stream_handler)


class Realm:
    """
    This module This module provides CLI interface to manage realm of the object gateway service.
    """

    def __init__(self, base_cmd):
        self.base_cmd = base_cmd + " realm"

    def create(self, **kw):
        """
        Creates a realm.
        If the realm is default if condition evaluates to true the realm will be set to default.
        otherwise else section executes and may have to specify the realm name each time we create zone_group and zone.
        Args:
          kw (Dict): Key/value pairs that needs to be provided to the installer.
          Example:
            Supported keys:
              rgw-realm(str): Takes the realm name as input.
              default(bool): True to create default realm , False for non-default realm.

        Returns:
          Dict(str)
            A mapping of host strings to the given task’s return value for that host’s execution run
        """
        kw = kw.get("kw")
        realm_name = kw.get("rgw-realm")
        default = kw.get("default")
        if default:
            cmd = self.base_cmd + f" create --rgw-realm={realm_name} --default"
        else:
            cmd = self.base_cmd + f" create --rgw-realm={realm_name}"
        logger.info(f"Running command {cmd}")
        return fabfile.run_command(cmd, config=kw.get("env_config"))

    def delete(self, **kw):
        """
        To delete a realm, execute realm delete and specify the realm name.
        Args:
          kw (Dict): Key/value pairs that needs to be provided to the installer.
          Example:
            Supported keys:
              rgw-realm(str): Takes the realm name as input.

        Returns:
          Dict(str)
            A mapping of host strings to the given task’s return value for that host’s execution run
        """
        kw = kw.get("kw")
        realm_name = kw.get("rgw-realm")
        cmd = self.base_cmd + f" delete --rgw-realm={realm_name}"
        logger.info(f"Running command {cmd}")
        return fabfile.run_command(cmd, config=kw.get("env_config"))

    def get_(self, **kw):
        """
        Takes a realm name as an input to fetch the details of the realm.
        Args:
          kw (Dict): Key/value pairs that needs to be provided to the installer.
          Example:
            Supported keys:
              rgw-realm(str): Takes the realm name as input.

        Returns:
          Dict(str)
            A mapping of host strings to the given task’s return value for that host’s execution run
        """
        kw = kw.get("kw")
        realm_name = kw.get("rgw-realm")
        cmd = self.base_cmd + f" get --rgw-realm={realm_name}"
        logger.info(f"Running command {cmd}")
        return fabfile.run_command(cmd, config=kw.get("env_config"))

    def default_(self, **kw):
        """
        Takes realm name as an input to set the realm as default one.
        Args:
          kw (Dict): Key/value pairs that needs to be provided to the installer.
          Example:
            Supported keys:
              rgw-realm(str): Takes the realm name as input.

        Returns:
          Dict(str)
            A mapping of host strings to the given task’s return value for that host’s execution run
        """
        kw = kw.get("kw")
        realm_name = kw.get("rgw-realm")
        cmd = self.base_cmd + f" default --rgw-realm={realm_name}"
        logger.info(f"Running command {cmd}")
        return fabfile.run_command(cmd, config=kw.get("env_config"))

    def list_(self, **kw):
        """
        This will list all the realms.
        Args:
          None

        Returns:
          Dict(str)
            A mapping of host strings to the given task’s return value for that host’s execution run
        """
        kw = kw.get("kw")
        cmd = self.base_cmd + " list"
        logger.info(f"Running command {cmd}")
        return fabfile.run_command(cmd, config=kw.get("env_config"))

    def list_periods(self, **kw):
        """
        This will list all the realm periods.
        Args:
          None

        Returns:
          Dict(str)
            A mapping of host strings to the given task’s return value for that host’s execution run
        """
        kw = kw.get("kw")
        cmd = self.base_cmd + " list-periods"
        logger.info(f"Running command {cmd}")
        return fabfile.run_command(cmd, config=kw.get("env_config"))

    def rename(self, **kw):
        """
        Renames a realm.
        Args:
          kw (Dict): Key/value pairs that needs to be provided to the installer.
          Example:
            Supported keys:
              rgw-realm(str): Takes the realm name as input.
              realm-new-name(str): Takes the new realm name as input.

        Returns:
          Dict(str)
            A mapping of host strings to the given task’s return value for that host’s execution run
        """
        kw = kw.get("kw")
        realm_name = kw.get("rgw-realm")
        new_realm_name = kw.get("realm-new-name")
        cmd = (
            self.base_cmd
            + f" rename --rgw-realm={realm_name} --realm-new-name={new_realm_name}"
        )
        logger.info(f"Running command {cmd}")
        return fabfile.run_command(cmd, config=kw.get("env_config"))

    def set_(self, **kw):
        """
        Takes realm name and infile name as an input to set the realm.
        Args:
          kw (Dict): Key/value pairs that needs to be provided to the installer.
          Example:
            Supported keys:
              rgw-realm(str): Takes the realm name as input.
              infile(str): Takes this json file as an input.

        Returns:
          Dict(str)
            A mapping of host strings to the given task’s return value for that host’s execution run
        """
        kw = kw.get("kw")
        realm_name = kw.get("rgw-realm")
        in_file = kw.get("infile")
        cmd = self.base_cmd + f" set --rgw-realm={realm_name} --infile={in_file}"
        logger.info(f"Running command {cmd}")
        return fabfile.run_command(cmd, config=kw.get("env_config"))

    def pull(self, **kw):
        """
        To pull a realm from the node containing the master zone group and master zone.
        Args:
          kw (Dict): Key/value pairs that needs to be provided to the installer.
          Example:
            Supported keys:
              url(str) : url to the master zone.
              access-key(str): The secondary zones will require them to authenticate with the master zone.
              secret-key(str): The secondary zones will require them to authenticate with the master zone.

        Returns:
          Dict(str)
            A mapping of host strings to the given task’s return value for that host’s execution run
        """
        kw = kw.get("kw")
        url = kw.get("url")
        access_key = kw.get("access-key")
        secret_key = kw.get("secret-key")
        cmd = (
            self.base_cmd
            + f" pull --url={url} --access-key={access_key} --secret={secret_key}"
        )
        logger.info(f"Running command {cmd}")
        return fabfile.run_command(cmd, config=kw.get("env_config"))

    def get_default(self, **kw):
        """
        lists out the default realm.
        Args:
          None

        Returns:
          Dict(str)
            A mapping of host strings to the given task’s return value for that host’s execution run
        """
        kw = kw.get("kw")
        cmd = self.base_cmd + " get-default"
        logger.info(f"Running command {cmd}")
        return fabfile.run_command(cmd, config=kw.get("env_config"))



import logging

import src.RhcsQeSdk.core.cli.fabfile as fabfile

logger = logging.getLogger(__name__)
logger.setLevel(logging.DEBUG)

formatter = logging.Formatter(
    "%(asctime)s - %(levelname)s - %(name)s:%(lineno)d - %(message)s"
)

stream_handler = logging.StreamHandler()
stream_handler.setFormatter(formatter)
stream_handler.setLevel(logging.DEBUG)
logger.addHandler(stream_handler)


class Bi:
    """
    This module provides CLI interface to manage bucket index operations.
    """

    def __init__(self, base_cmd):
        self.base_cmd = base_cmd + " bi"

    def list_(self, **kw):
        """List raw bucket index entries.
        Args:
                kw(dict): Key/value pairs that needs to be provided to the installer
        Example::
        Supported keys:
                bucket(str): takes name of the bucket
        Returns:
            Dict(str)
            A mapping of host strings to the given task’s return value for that host’s execution run
        """
        kw = kw.get("kw")
        bucket_name = kw.get("bucket")
        cmd = (
            self.base_cmd + f" list --bucket={bucket_name} > {bucket_name}.list.backup"
        )
        logger.info(f"Running command {cmd}")
        return fabfile.run_command(cmd, config=kw.get("env_config"))

    def purge(self, **kw):
        """Purge bucket index entries.
        Args:
                kw(dict): Key/value pairs that needs to be provided to the installer
        Example::
        Supported keys:
                bucket(str): takes name of the bucket
                bucket-id(str): takes old bucket ID
        Returns:
            Dict(str)
            A mapping of host strings to the given task’s return value for that host’s execution run
        """
        kw = kw.get("kw")
        bucket_name = kw.get("bucket")
        old_bucket_id = kw.get("bucket-id")
        cmd = (
            self.base_cmd + f" purge --bucket={bucket_name} --bucket-id={old_bucket_id}"
        )
        logger.info(f"Running command {cmd}")
        return fabfile.run_command(cmd, config=kw.get("env_config"))



import logging
from copy import deepcopy

import src.RhcsQeSdk.core.cli.fabfile as fabfile
from src.RhcsQeSdk.core.utilities import core_utils

logger = logging.getLogger(__name__)
logger.setLevel(logging.DEBUG)

formatter = logging.Formatter(
    "%(asctime)s - %(levelname)s - %(name)s:%(lineno)d - %(message)s"
)

stream_handler = logging.StreamHandler()
stream_handler.setFormatter(formatter)
stream_handler.setLevel(logging.DEBUG)
logger.addHandler(stream_handler)


class Zone:
    """
    This module provides CLI interface for zone management of object gateway service.
    """

    def __init__(self, base_cmd):
        self.base_cmd = base_cmd + " zone"

    def create(self, **kw):
        """
        To create a zone, specify a zone name.
        Args:
          kw (Dict): Key/value pairs that needs to be provided to the installer.
          Example:
            Supported keys:
              rgw-zone(str) : Takes the zone name as an input.
              rgw-zonegroup(str) : Takes the zone group name as an input.
              endpoints(str) : combination of an endpoint and port number.
              default(bool) : True to create default zone , False for non-default zone.
              rgw-realm(str): Takes the realm name as input.
              access-key(str):The secondary zones will require them to authenticate with the master zone.
              secret-key(str):The secondary zones will require them to authenticate with the master zone.

        Returns:
          Dict(str)
            A mapping of host strings to the given task’s return value for that host’s execution run
        """
        kw = kw.get("kw")
        kw_copy = deepcopy(kw)
        zonegroup_name = kw_copy.pop("rgw-zonegroup", "")
        rgw_zone = kw_copy.pop("rgw-zone", "")
        cmd_args = core_utils.build_cmd_args(kw=kw_copy)
        cmd = (
            self.base_cmd
            + f" create --rgw-zonegroup={zonegroup_name} --rgw-zone={rgw_zone}"
            + cmd_args
        )
        logger.info(f"Running command {cmd}")
        return fabfile.run_command(cmd, config=kw.get("env_config"))

    def delete(self, **kw):
        """
        To delete a zone, first remove it from the zonegroup.
        Then, update the period and delete the zone.
        Then again re-update the period.
        Args:
          kw (Dict): Key/value pairs that needs to be provided to the installer.
          Example:
            Supported keys:
              rgw-zone(str) : Takes the zone name as an input.

        Returns:
          Dict(str)
            A mapping of host strings to the given task’s return value for that host’s execution run
        """
        kw = kw.get("kw")
        rgw_zone = kw.get("rgw-zone")
        cmd = self.base_cmd + f" delete --rgw-zone={rgw_zone}"
        logger.info(f"Running command {cmd}")
        return fabfile.run_command(cmd, config=kw.get("env_config"))

    def modify(self, **kw):
        """
        To modify a zone, specify the zone name and the parameters you wish to modify.
        If the cluster was configured to run in an active-passive configuration, the secondary zone is a read-only zone.
        Remove the --read-only status to allow the zone to receive write operations.
        Args:
          kw (Dict): Key/value pairs that needs to be provided to the installer.
          Example:
            Supported keys:
              rgw-zone(str) : Takes the zone name as an input.
              access-key(str): The secondary zones will require them to authenticate with the master zone.
              secret-key(str): The secondary zones will require them to authenticate with the master zone.
              endpoints(str): url to the master zone.
              read-only(str): set the --read-only status to allow the zone to receive write operations.

        Returns:
          Dict(str)
            A mapping of host strings to the given task’s return value for that host’s execution run
        """
        kw = kw.get("kw")

        cmd = self.base_cmd + " modify " + core_utils.build_cmd_args(kw=kw)
        logger.info(f"Running command {cmd}")
        return fabfile.run_command(cmd, config=kw.get("env_config"))

    def set_(self, **kw):
        """
        It Set zone cluster params.
        To set a zone, create a JSON object consisting of the pools, save the object to a file (e.g., zone.json).
        Args:
          kw (Dict): Key/value pairs that needs to be provided to the installer.
          Example:
            Supported keys:
              rgw-zone(str) : Takes the zone name as an input.
              infile(JSON) : Takes the Json file as an input.

        Returns:
          Dict(str)
            A mapping of host strings to the given task’s return value for that host’s execution run
        """
        kw = kw.get("kw")
        rgw_zone = kw.get("rgw-zone")
        in_file = kw.get("infile")
        cmd = self.base_cmd + f" set --rgw-zone={rgw_zone} --infile={in_file}"
        logger.info(f"Running command {cmd}")
        return fabfile.run_command(cmd, config=kw.get("env_config"))

    def rename(self, **kw):
        """
        To rename a zone, specify the zone name and the new zone name.
        Args:
          kw (Dict): Key/value pairs that needs to be provided to the installer.
          Example:
            Supported keys:
              rgw-zone(str) : Takes the zone name as an input.
              zone-new-name(str) : Takes the new zone name as an input.

        Returns:
          Dict(str)
            A mapping of host strings to the given task’s return value for that host’s execution run
        """
        kw = kw.get("kw")
        rgw_zone = kw.get("rgw-zone")
        zone_new_name = kw.get("zone-new-name")
        cmd = (
            self.base_cmd
            + f" rename --rgw-zone={rgw_zone} --zone-new-name={zone_new_name}"
        )
        logger.info(f"Running command {cmd}")
        return fabfile.run_command(cmd, config=kw.get("env_config"))

    def get_(self, **kw):
        """
        This method is used to fetch the configuration of a zone.
        Args:
          kw (Dict): Key/value pairs that needs to be provided to the installer.
          Example:
            Supported keys:
              rgw-zone(str) : Takes the zone name as an input.

        Returns:
          Dict(str)
            A mapping of host strings to the given task’s return value for that host’s execution run
        """
        kw = kw.get("kw")
        rgw_zone = kw.get("rgw-zone")
        cmd = self.base_cmd + f" get --rgw-zone={rgw_zone}"
        logger.info(f"Running command {cmd}")
        return fabfile.run_command(cmd, config=kw.get("env_config"))

    def list_(self, **kw):
        """
        List the zones in a cluster.
        Args:
          None

        Returns:
          Dict(str)
            A mapping of host strings to the given task’s return value for that host’s execution run
        """
        kw = kw.get("kw")
        cmd = self.base_cmd + " list"
        logger.info(f"Running command {cmd}")
        return fabfile.run_command(cmd, config=kw.get("env_config"))



import logging
from copy import deepcopy

import src.RhcsQeSdk.core.cli.fabfile as fabfile
from src.RhcsQeSdk.core.utilities import core_utils

logger = logging.getLogger(__name__)
logger.setLevel(logging.DEBUG)

formatter = logging.Formatter(
    "%(asctime)s - %(levelname)s - %(name)s:%(lineno)d - %(message)s"
)

stream_handler = logging.StreamHandler()
stream_handler.setFormatter(formatter)
stream_handler.setLevel(logging.DEBUG)
logger.addHandler(stream_handler)


class Schedule:
    """
    This module provides CLI interface to rbd trash purge schedule commands.
    """

    def __init__(self, base_cmd):
        self.base_cmd = base_cmd + " schedule"

    def add_(self, **kw):
        """Wrapper for rbd trash purge schedule add.

        Add trash purge schedule.
        Args:
        kw: Key value pair of method arguments
            Example::
            Supported keys:
                pool(str): pool name
                namespace(str): name of the namespace
                interval(str): schedule interval
                start-time: optional schedule start time
        Returns:
            Dict(str):
            A mapping of host strings to the given task's return value for that host's execution run.
        """
        kw = kw.get("kw")

        kw_copy = deepcopy(kw)
        interval = kw_copy.pop("interval", "")
        start_time = kw_copy.pop("start-time", "")
        cmd_args = core_utils.build_cmd_args(kw=kw_copy)

        cmd = f"{self.base_cmd} add {interval} {start_time}{cmd_args}"
        logger.info(f"Running command {cmd}")
        return fabfile.run_command(cmd, config=kw.get("env_config"))

    def ls(self, **kw):
        """Wrapper for rbd trash purge schedule ls.

        List trash purge schedule.
        Args:
        kw: Key value pair of method arguments
            Example::
            Supported keys:
                pool(str): pool name.
                namespace(str): name of the namespace.
                recursive(bool): list all schedules.
                format(str): output format (plain, json, or xml) [default: plain]
                pretty-format(bool): True
        Returns:
            Dict(str):
            A mapping of host strings to the given task's return value for that host's execution run.
        """
        kw = kw.get("kw")
        cmd_args = core_utils.build_cmd_args(kw=kw)

        cmd = f"{self.base_cmd} ls{cmd_args}"
        logger.info(f"Running command {cmd}")
        return fabfile.run_command(cmd, config=kw.get("env_config"))

    def rm(self, **kw):
        """Wrapper for rbd trash purge schedule rm.

        Remove trash purge schedule.
        Args:
        kw: Key value pair of method arguments
            Example::
            Supported keys:
                pool(str): pool name.
                namespace(str): name of the namespace.
                interval(str): schedule interval
                start-time: optional schedule start time
        Returns:
            Dict(str):
            A mapping of host strings to the given task's return value for that host's execution run.
        """
        kw = kw.get("kw")

        kw_copy = deepcopy(kw)
        interval = kw_copy.pop("interval", "")
        start_time = kw_copy.pop("start-time", "")
        cmd_args = core_utils.build_cmd_args(kw=kw_copy)

        cmd = f"{self.base_cmd} rm {interval} {start_time}{cmd_args}"
        logger.info(f"Running command {cmd}")
        return fabfile.run_command(cmd, config=kw.get("env_config"))

    def status(self, **kw):
        """Wrapper for rbd trash purge schedule status.

        Show trash purge schedule status.
        Args:
        kw: Key value pair of method arguments
            Example::
            Supported keys:
                pool(str): pool name.
                namespace(str): name of the namespace.
                format(str): output format (plain, json, or xml) [default: plain]
                pretty-format(bool): True
        Returns:
            Dict(str):
            A mapping of host strings to the given task's return value for that host's execution run.
        """
        kw = kw.get("kw")
        cmd_args = core_utils.build_cmd_args(kw=kw)

        cmd = f"{self.base_cmd} status{cmd_args}"
        logger.info(f"Running command {cmd}")
        return fabfile.run_command(cmd, config=kw.get("env_config"))



import logging

import src.RhcsQeSdk.core.cli.fabfile as fabfile
from src.RhcsQeSdk.core.cli.ceph.auth import Auth
from src.RhcsQeSdk.core.cli.ceph.balancer import Balancer
from src.RhcsQeSdk.core.cli.ceph.cephadm import CephAdm
from src.RhcsQeSdk.core.cli.ceph.config import Config
from src.RhcsQeSdk.core.cli.ceph.config_key import ConfigKey
from src.RhcsQeSdk.core.cli.ceph.health import Health
from src.RhcsQeSdk.core.cli.ceph.mds import Mds
from src.RhcsQeSdk.core.cli.ceph.mgr import Mgr
from src.RhcsQeSdk.core.cli.ceph.mon import Mon
from src.RhcsQeSdk.core.cli.ceph.orch.orch import Orch
from src.RhcsQeSdk.core.cli.ceph.osd import Osd

logger = logging.getLogger(__name__)
logger.setLevel(logging.DEBUG)

formatter = logging.Formatter(
    "%(asctime)s - %(levelname)s - %(name)s:%(lineno)d - %(message)s"
)

stream_handler = logging.StreamHandler()
stream_handler.setFormatter(formatter)
stream_handler.setLevel(logging.DEBUG)
logger.addHandler(stream_handler)


class Ceph:
    """This module provides CLI interface for deployment and maintenance of ceph cluster."""

    def __init__(self, base_cmd=""):
        self.base_cmd = f"{base_cmd}ceph"
        self.config = Config(self.base_cmd)
        self.osd = Osd(self.base_cmd)
        self.auth = Auth(self.base_cmd)
        self.cephadm = CephAdm(self.base_cmd)
        self.orch = Orch(self.base_cmd)
        self.health = Health(self.base_cmd)
        self.balancer = Balancer(self.base_cmd)
        self.configkey = ConfigKey(self.base_cmd)
        self.mds = Mds(self.base_cmd)
        self.mon = Mon(self.base_cmd)
        self.mgr = Mgr(self.base_cmd)

    def version(self, **kw):
        """
        The command version will display the mon daemon version.

        Args:
            kw(Dict): Key/value pairs that needs to be provided to the installer.
            Example::
            Supported Keys:

            None

        Returns:
            Dict(str)
            A mapping of host strings to the given task's return value for that host's execution run.
        """
        kw = kw.get("kw")
        cmd = self.base_cmd + " version"
        logger.info(f"Running command {cmd}")
        return fabfile.run_command(cmd, config=kw.get("env_config"))

    def status(self, **kw):
        """
        This method is used to show cluster status.
        Args:
          None
        Returns:
            Dict(str)
            A mapping of host strings to the given task's return value for that host's execution run.
        """
        kw = kw.get("kw")
        cmd = self.base_cmd + " status"
        logger.info(f"Running command {cmd}")
        return fabfile.run_command(cmd, config=kw.get("env_config"))

    def quorum_status(self, **kw):
        """
        This method is used to report the status of monitor quorum.
        Args:
          None
        Returns:
            Dict(str)
            A mapping of host strings to the given task's return value for that host's execution run.
        """
        kw = kw.get("kw")
        cmd = self.base_cmd + " quorum_status"
        logger.info(f"Running command {cmd}")
        return fabfile.run_command(cmd, config=kw.get("env_config"))

    def daemon(self, **kw):
        """Submit admin-socket commands.
        Args:
                kw(dict): Key/value pairs that needs to be provided to the installer
        Example::
        Supported keys:
                daemon-name(str): takes name of the daemon
                path-to-socket-file(str): takes path to the socket file
                command(str): takes input the command
        Returns:
            Dict(str)
            A mapping of host strings to the given task’s return value for that host’s execution run
        """
        kw = kw.get("kw")
        daemon_name = kw.get("daemon-name", "")
        path_to_socket_file = kw.get("path-to-socket-file", "")
        command = kw.get("command", "")
        cmd = self.base_cmd + f" daemon {daemon_name}{path_to_socket_file} {command}"
        logger.info(f"Running command {cmd}")
        return fabfile.run_command(cmd, config=kw.get("env_config"))

    def log(self, **kw):
        """Log supplied text to the monitor log.
        Args:
            kw(dict): Key/value pairs that needs to be provided to the installer
        Example::
        Supported keys:
                logtext(str): takes the logtext
                command(str): takes input the command
        Returns:
            Dict(str)
            A mapping of host strings to the given task’s return value for that host’s execution run
        """
        kw = kw.get("kw")
        logtext = kw.get("logtext", "")
        command = kw.get("command", "")
        cmd = self.base_cmd + f" log {command} [{logtext}]"
        logger.info(f"Running command {cmd}")
        return fabfile.run_command(cmd, config=kw.get("env_config"))

    def df(self, **kw):
        """
        The command df will display the cluster's free space status.
        Args:
            detail(str): to show more information about the cluster.
        Returns:
            Dict(str)
            A mapping of host strings to the given task's return value for that host's execution run.
        """
        kw = kw.get("kw")
        cmd = self.base_cmd + " df" + (" detail" if kw.get("detail") else "")
        logger.info(f"Running command {cmd}")
        return fabfile.run_command(cmd, config=kw.get("env_config"))



import logging
from copy import deepcopy

import src.RhcsQeSdk.core.cli.fabfile as fabfile
from src.RhcsQeSdk.core.utilities import core_utils

logger = logging.getLogger(__name__)
logger.setLevel(logging.DEBUG)

formatter = logging.Formatter(
    "%(asctime)s - %(levelname)s - %(name)s:%(lineno)d - %(message)s"
)

stream_handler = logging.StreamHandler()
stream_handler.setFormatter(formatter)
stream_handler.setLevel(logging.DEBUG)
logger.addHandler(stream_handler)


class Image:
    """This module provides CLI interface to manage rbd mirror image commands."""

    def __init__(self, base_cmd):
        self.base_cmd = base_cmd + " image"

    def demote(self, **kw):
        """Wrapper for rbd mirror image demote.

        Args:
            kw: Key value pair of method arguments
        Example::
        Supported keys:
            image_spec: poolname/[namespace]/imagename
            pool_name: Name of the pool.
            namespace: Name of the namespace.
            image: Name of the image.
        Returns:
            Dict(str):
            A mapping of host strings to the given task's return value for that host's execution run.
        """
        kw = kw.get("kw")

        kw_copy = deepcopy(kw)
        image_spec = kw_copy.pop("image_spec", "")
        cmd_args = core_utils.build_cmd_args(kw=kw_copy)

        cmd = f"{self.base_cmd} demote {image_spec}{cmd_args}"
        logger.info(f"Running command {cmd}")
        return fabfile.run_command(cmd, config=kw.get("env_config"))

    def disable(self, **kw):
        """Wrapper for rbd mirror image disable.

        Args
            kw: Key value pair of method arguments

        Example::
        Supported keys:
            image_spec: poolname/[namespace]/imagename
            pool_name: Name of the pool.
            namespace: Name of the namespace.
            image: Name of the image.
        Returns:
            Dict(str):
            A mapping of host strings to the given task's return value for that host's execution run.
        """
        kw = kw.get("kw")

        kw_copy = deepcopy(kw)
        image_spec = kw_copy.pop("image_spec", "")
        cmd_args = core_utils.build_cmd_args(kw=kw_copy)

        cmd = f"{self.base_cmd} disable {image_spec}{cmd_args}"
        logger.info(f"Running command {cmd}")
        return fabfile.run_command(cmd, config=kw.get("env_config"))

    def enable(self, **kw):
        """Wrapper for rbd mirror image enable.

        Args
            kw: Key value pair of method arguments
            Example::
            Supported keys:
                image_spec: poolname/[namespace]/imagename
                pool_name: Name of the pool.
                namespace: Name of the namespace.
                image: Name of the image.
                mode: Mode of mirroring(journal/snapshot) [default: journal]
        Returns:
            Dict(str):
            A mapping of host strings to the given task's return value for that host's execution run.
        """
        kw = kw.get("kw")

        kw_copy = deepcopy(kw)
        image_spec = kw_copy.pop("image_spec", "")
        mode = kw_copy.pop("mode", "")
        cmd_args = core_utils.build_cmd_args(kw=kw_copy)

        cmd = f"{self.base_cmd} enable {image_spec} {mode}{cmd_args}"
        logger.info(f"Running command {cmd}")
        return fabfile.run_command(cmd, config=kw.get("env_config"))

    def promote(self, **kw):
        """Wrapper for rbd mirror image promote.

        Args:
            kw: Key value pair of method arguments
            Example::
            Supported keys:
                image_spec: poolname/[namespace]/imagename
                pool_name: Name of the pool.
                namespace: Name of the namespace.
                image: Name of the image.
                force(bool): True - To promote image forcefully
        Returns:
            Dict(str):
            A mapping of host strings to the given task's return value for that host's execution run.
        """
        kw = kw.get("kw")

        kw_copy = deepcopy(kw)
        image_spec = kw_copy.pop("image_spec", "")
        cmd_args = core_utils.build_cmd_args(kw=kw_copy)

        cmd = f"{self.base_cmd} promote {image_spec}{cmd_args}"
        logger.info(f"Running command {cmd}")
        return fabfile.run_command(cmd, config=kw.get("env_config"))

    def resync(self, **kw):
        """Wrapper for rbd mirror image resync.

        Args:
            kw: Key value pair of method arguments
            Example::
            Supported keys:
                image_spec: poolname/[namespace]/imagename
                pool_name: Name of the pool.
                namespace: Name of the namespace.
                image: Name of the image.
        Returns:
            Dict(str):
            A mapping of host strings to the given task's return value for that host's execution run.
        """
        kw = kw.get("kw")

        kw_copy = deepcopy(kw)
        image_spec = kw_copy.pop("image_spec", "")
        cmd_args = core_utils.build_cmd_args(kw=kw_copy)

        cmd = f"{self.base_cmd} resync {image_spec}{cmd_args}"
        logger.info(f"Running command {cmd}")
        return fabfile.run_command(cmd, config=kw.get("env_config"))

    def snapshot(self, **kw):
        """Wrapper for rbd mirror image snapshot.

        Args:
            kw: Key value pair of method arguments
            Example::
            Supported keys:
                image_spec: poolname/[namespace]/imagename
                pool_name: Name of the pool.
                namespace: Name of the namespace.
                image: Name of the image.
        Returns:
            Dict(str):
            A mapping of host strings to the given task's return value for that host's execution run.
        """
        kw = kw.get("kw")

        kw_copy = deepcopy(kw)
        image_spec = kw_copy.pop("image_spec", "")
        cmd_args = core_utils.build_cmd_args(kw=kw_copy)

        cmd = f"{self.base_cmd} snapshot {image_spec}{cmd_args}"
        logger.info(f"Running command {cmd}")
        return fabfile.run_command(cmd, config=kw.get("env_config"))

    def status(self, **kw):
        """Wrapper for rbd mirror image status.

        Args:
            kw: Key value pair of method arguments
            Example::
            Supported keys:
                format: output format (plain, json, or xml) [default: plain]
                pretty-format: true - pretty formatting (json and xml)
                image_spec: poolname/[namespace]/imagename
                pool_name: Name of the pool.
                namespace: Name of the namespace.
                image: Name of the image.
        Returns:
            Dict(str):
            A mapping of host strings to the given task's return value for that host's execution run.
        """
        kw = kw.get("kw")

        kw_copy = deepcopy(kw)
        image_spec = kw_copy.pop("image_spec", "")
        cmd_args = core_utils.build_cmd_args(kw=kw_copy)

        cmd = f"{self.base_cmd} status {image_spec}{cmd_args}"
        logger.info(f"Running command {cmd}")
        return fabfile.run_command(cmd, config=kw.get("env_config"))



import logging
from copy import deepcopy

import src.RhcsQeSdk.core.cli.fabfile as fabfile
from src.RhcsQeSdk.core.utilities import core_utils

logger = logging.getLogger(__name__)
logger.setLevel(logging.DEBUG)

formatter = logging.Formatter(
    "%(asctime)s - %(levelname)s - %(name)s:%(lineno)d - %(message)s"
)

stream_handler = logging.StreamHandler()
stream_handler.setFormatter(formatter)
stream_handler.setLevel(logging.DEBUG)
logger.addHandler(stream_handler)


base_cmd_osd = None
rm_obj = None


class OsdRm:
    """
    This module provides CLI interface to ceph orch osd rm sub-commands.
    """

    def __new__(self, **kw):
        """To Remove OSD daemons.
        <osd_id>... [--replace] [--force] [--zap]
        Args:
        kw: Key value pair of method arguments
            Example::
            Supported keys:
                osd-id: id of osd to be removed.
                replace(bool): Replace osd.
                force(bool): force removal.
                zap(bool): zap disks.
        Returns:
          Dict(str)
            A mapping of host strings to the given task’s return value for that host’s execution run
        """
        kw = kw.get("kw")

        kw_copy = deepcopy(kw)
        osd_id = kw_copy.pop("osd-id", "")
        global base_cmd_osd
        cmd_args = core_utils.build_cmd_args(kw=kw_copy)

        cmd = base_cmd_osd + f" rm {osd_id}{cmd_args}"
        logger.info(f"Running command {cmd}")
        return fabfile.run_command(cmd, config=kw.get("env_config"))

    @staticmethod
    def status(**kw):
        """Wrapper for command ceph orch osd status

        Status of OSD removal operation.
        Args:
            kw(dict): Key/value pairs that needs to be provided to the installer
            Example::
            Supported keys:
                format(str): {plain|json|json-pretty|yaml|xml-pretty|xml}
        Returns:
          Dict(str)
            A mapping of host strings to the given task’s return value for that host’s execution run
        """
        kw = kw.get("kw")
        global base_cmd_osd
        cmd_args = core_utils.build_cmd_args(kw=kw)

        cmd = base_cmd_osd + f" rm status{cmd_args}"
        logger.info(f"Running command {cmd}")
        return fabfile.run_command(cmd, config=kw.get("env_config"))

    @staticmethod
    def stop(**kw):
        """Wrapper for command ceph orch osd stop.

        Cancel ongoing OSD removal operation.
        Args:
            kw(dict): Key/value pairs that needs to be provided to the installer
            Example::
            Supported keys:
                osd-id: id of osd of which removal to be stopped.
        Returns:
          Dict(str)
            A mapping of host strings to the given task’s return value for that host’s execution run
        """
        kw = kw.get("kw")

        kw_copy = deepcopy(kw)
        osd_id = kw_copy.pop("osd-id", "")
        global base_cmd_osd

        cmd = base_cmd_osd + f" rm stop {osd_id}"
        logger.info(f"Running command {cmd}")
        return fabfile.run_command(cmd, config=kw.get("env_config"))


class Rm:
    """
    This module provides abstract CLI interface to ceph orch osd rm sub-commands.
    """

    def __new__(self, base_cmd):
        global base_cmd_osd
        base_cmd_osd = base_cmd
        self.base_cmd = base_cmd + " rm"
        return OsdRm



import logging

import src.RhcsQeSdk.core.cli.fabfile as fabfile

logger = logging.getLogger(__name__)
logger.setLevel(logging.DEBUG)

formatter = logging.Formatter(
    "%(asctime)s - %(levelname)s - %(name)s:%(lineno)d - %(message)s"
)

stream_handler = logging.StreamHandler()
stream_handler.setFormatter(formatter)
stream_handler.setLevel(logging.DEBUG)
logger.addHandler(stream_handler)


class Rule:
    """
    This module provides CLI interface to implement CRUSH rules that defines
    how a Ceph client selects a bucket and OSD to store objects.
    """

    def __init__(self, base_cmd):
        self.base_cmd = base_cmd + " rule"

    def dump(self, **kw):
        """
        The command dump will dump a crush rule.

        Args:
            kw(Dict): Key/value pairs that needs to be provided to the installer.
            Example::
            Supported Keys:

            crush_rule_name(str): name of the crush rule.

        Returns:
            Dict(str)
            A mapping of host strings to the given task's return value for that host's execution run
        """
        kw = kw.get("kw")
        crush_rule_name = kw.get("crush_rule_name", "")
        cmd = self.base_cmd + f" dump {crush_rule_name}"
        logger.info(f"Running command {cmd}")
        return fabfile.run_command(cmd, config=kw.get("env_config"))

    def ls(self, **kw):
        """
        The command ls will list the crush rules.

        Args:
            kw(Dict): Key/value pairs that needs to be provided to the installer.
            Example::
            Supported Keys:

            None

        Returns:
            Dict(str)
            A mapping of host strings to the given task's return value for that host's execution run
        """
        kw = kw.get("kw")
        cmd = self.base_cmd + " ls"
        logger.info(f"Running command {cmd}")
        return fabfile.run_command(cmd, config=kw.get("env_config"))

    def rm(self, **kw):
        """
        The command rm removes a crush rule.

        Args:
            kw(Dict): Key/value pairs that needs to be provided to the installer.
            Example::
            Supported Keys:

            crush_rule_name(str): name of the crush rule.

        Returns:
            Dict(str)
            A mapping of host strings to the given task's return value for that host's execution run
        """
        kw = kw.get("kw")
        crush_rule_name = kw.get("crush_rule_name", "")
        cmd = self.base_cmd + f" rm {crush_rule_name}"
        logger.info(f"Running command {cmd}")
        return fabfile.run_command(cmd, config=kw.get("env_config"))

    def create_erasure(self, **kw):
        """
        The command create-erasure will create a crush rule for erasure coded pool with a profile.

        Args:
            kw(Dict): Key/value pairs that needs to be provided to the installer.
            Example::
            Supported Keys:

            crush_rule_name(str): name of the crush rule.
            profile(str): type of profile.

        Returns:
            Dict(str)
            A mapping of host strings to the given task's return value for that host's execution run
        """
        kw = kw.get("kw")
        crush_rule_name = kw.get("crush_rule_name", "")
        profile = kw.get("profile", "")
        cmd = self.base_cmd + f" create-erasure {crush_rule_name} {profile}"
        logger.info(f"Running command {cmd}")
        return fabfile.run_command(cmd, config=kw.get("env_config"))

    def create_simple(self, **kw):
        """
        The command create-simple will create a crush rule
        from the root and replicate it to a bucket type using
        a particular mode.

        Args:
            kw(Dict): Key/value pairs that needs to be provided to the installer.
            Example::
            Supported Keys:

            crush_rule_name(str): name of the crush rule.
            root(str): location where the node has to be linked.
            bucket_type(str): type of the bucket.
            mode_type(str): type of the choose mode.(either firstn (default) or indep)

        Returns:
            Dict(str)
            A mapping of host strings to the given task's return value for that host's execution run
        """
        kw = kw.get("kw")
        crush_rule_name = kw.get("crush_rule_name", "")
        root = kw.get("root", "")
        bucket_type = kw.get("bucket_type", "")
        mode_type = kw.get("mode_type", "firstn")
        cmd = (
            self.base_cmd
            + f" create-simple {crush_rule_name} {root} {bucket_type} {mode_type}"
        )
        logger.info(f"Running command {cmd}")
        return fabfile.run_command(cmd, config=kw.get("env_config"))



import logging

import src.RhcsQeSdk.core.cli.fabfile as fabfile

logger = logging.getLogger(__name__)
logger.setLevel(logging.DEBUG)

formatter = logging.Formatter(
    "%(asctime)s - %(levelname)s - %(name)s:%(lineno)d - %(message)s"
)

stream_handler = logging.StreamHandler()
stream_handler.setFormatter(formatter)
stream_handler.setLevel(logging.DEBUG)
logger.addHandler(stream_handler)


class CephAdm:
    """
    This module provides a command line interface (CLI) to ceph cephadm.
    """

    def __init__(self, base_cmd):
        self.base_cmd = base_cmd + " cephadm"

    def generate_key(self, **kw):
        """
        Generates a new SSH key.
        Args:
            None
        Returns:
          Dict(str)
            A mapping of host strings to the given task’s return value for that host’s execution run
        """
        kw = kw.get("kw")
        cmd = self.base_cmd + " generate-key"
        logger.info(f"Running command {cmd}")
        return fabfile.run_command(cmd, config=kw.get("env_config"))

    def get_pub_key(self, **kw):
        """
        Retrieves a public portion of the SSH key .
        Args:
            None
        Returns:
          Dict(str)
            A mapping of host strings to the given task’s return value for that host’s execution run
        """
        kw = kw.get("kw")
        output_file = kw.get("output_file")
        cmd = f"{self.base_cmd} get-pub-key > {output_file}"
        logger.info(f"Running command {cmd}")
        return fabfile.run_command(cmd, config=kw.get("env_config"))

    def clear_key(self, **kw):
        """
        Deletes a currently stored SSH key.
        Args:
            None
        Returns:
          Dict(str)
            A mapping of host strings to the given task’s return value for that host’s execution run
        """
        kw = kw.get("kw")
        cmd = self.base_cmd + " clear-key"
        logger.info(f"Running command {cmd}")
        return fabfile.run_command(cmd, config=kw.get("env_config"))

    def set_user(self, **kw):
        """
        Sets user to perform all cephadm operations.
        Args:
            None
        Returns:
          Dict(str)
            A mapping of host strings to the given task’s return value for that host’s execution run
        """
        kw = kw.get("kw")
        cmd = self.base_cmd + " set-user"
        logger.info(f"Running command {cmd}")
        return fabfile.run_command(cmd, config=kw.get("env_config"))

    def set_ssh_config(self, **kw):
        """
        Imports a customized configuration file that will be stored by the monitor.
        Args:
          kw (Dict): Key/value pairs that needs to be provided to the installer.
          Example:
            Supported keys:
              ssh_config_file(str): SSH customized configuration file.
        Returns:
        Returns:
          Dict(str)
            A mapping of host strings to the given task’s return value for that host’s execution run
        """
        kw = kw.get("kw")
        ssh_config_file = kw.get("ssh_config_file")
        cmd = self.base_cmd + f" set-ssh-config -i {ssh_config_file}"
        logger.info(f"Running command {cmd}")
        return fabfile.run_command(cmd, config=kw.get("env_config"))

    def clear_ssh_config(self, **kw):
        """
        Removes a customized SSH config and revert back to the default behavior.
        Args:
            None
        Returns:
          Dict(str)
            A mapping of host strings to the given task’s return value for that host’s execution run
        """
        kw = kw.get("kw")
        cmd = self.base_cmd + " clear-ssh-config"
        logger.info(f"Running command {cmd}")
        return fabfile.run_command(cmd, config=kw.get("env_config"))



import logging

import src.RhcsQeSdk.core.cli.fabfile as fabfile

logger = logging.getLogger(__name__)
logger.setLevel(logging.DEBUG)

formatter = logging.Formatter(
    "%(asctime)s - %(levelname)s - %(name)s:%(lineno)d - %(message)s"
)

stream_handler = logging.StreamHandler()
stream_handler.setFormatter(formatter)
stream_handler.setLevel(logging.DEBUG)
logger.addHandler(stream_handler)


class Feature:
    """
    This module provides CLI interface to manage enabling and disabling image features.
    """

    def __init__(self, base_cmd):
        self.base_cmd = base_cmd + " feature"

    def enable(self, **kw):
        """
        This method is used to enable a image feature.
        Args:
          kw(dict): Key/value pairs that needs to be provided to the installer
          Example:
            Supported keys:
              pool_name(str): name of the pool.
              image_name(str): name of the image.
              feature_name(str): name of the feature.

        Returns:
          Dict(str)
            A mapping of host strings to the given task’s return value for that host’s execution run
        """
        kw = kw.get("kw")
        image_name = kw.get("image_name")
        pool_name = kw.get("pool_name")
        feature_name = kw.get("feature_name")
        cmd = self.base_cmd + " enable" + f" {pool_name}/{image_name} {feature_name}"
        logger.info(f"Running command {cmd}")
        return fabfile.run_command(cmd, config=kw.get("env_config"))

    def disable(self, **kw):
        """
        This method is used to disable a image feature.
        Args:
          kw(dict): Key/value pairs that needs to be provided to the installer
          Example:
            Supported keys:
              pool_name(str): name of the pool.
              image_name(str): name of the image.
              feature_name(str): name of the feature.

        Returns:
          Dict(str)
            A mapping of host strings to the given task’s return value for that host’s execution run
        """
        kw = kw.get("kw")
        image_name = kw.get("image_name")
        pool_name = kw.get("pool_name")
        feature_name = kw.get("feature_name")
        cmd = self.base_cmd + " disable" + f" {pool_name}/{image_name} {feature_name}"
        logger.info(f"Running command {cmd}")
        return fabfile.run_command(cmd, config=kw.get("env_config"))



import logging

import src.RhcsQeSdk.core.cli.fabfile as fabfile

logger = logging.getLogger(__name__)
logger.setLevel(logging.DEBUG)

formatter = logging.Formatter(
    "%(asctime)s - %(levelname)s - %(name)s:%(lineno)d - %(message)s"
)

stream_handler = logging.StreamHandler()
stream_handler.setFormatter(formatter)
stream_handler.setLevel(logging.DEBUG)
logger.addHandler(stream_handler)


class Object:
    """
    This module provides CLI interface to manage object operations for radosgw-admin.
    """

    def __init__(self, base_cmd):
        self.base_cmd = base_cmd + " object"

    def rm(self, **kw):
        """Remove an object from a bucket.
        Args:
                kw(dict): Key/value pairs that needs to be provided to the installer
        Example::
        Supported keys:
                object(str): takes name of the object
                bucket(str): takes name of the bucket
        Returns:
            Dict(str)
            A mapping of host strings to the given task’s return value for that host’s execution run
        """
        kw = kw.get("kw")
        object_name = kw.get("object")
        bucket_name = kw.get("bucket")
        cmd = self.base_cmd + f" rm --object={object_name} --bucket={bucket_name}"
        logger.info(f"Running command {cmd}")
        return fabfile.run_command(cmd, config=kw.get("env_config"))

    def stat(self, **kw):
        """Stat an object for its metadata.
        Args:
                kw(dict): Key/value pairs that needs to be provided to the installer
        Example::
        Supported keys:
                object(str): takes name of the object
                bucket(str): takes name of the bucket
        Returns:
            Dict(str)
            A mapping of host strings to the given task’s return value for that host’s execution run
        """
        kw = kw.get("kw")
        object_name = kw.get("object")
        bucket_name = kw.get("bucket")
        cmd = self.base_cmd + f" stat --bucket={bucket_name} --object={object_name}"
        logger.info(f"Running command {cmd}")
        return fabfile.run_command(cmd, config=kw.get("env_config"))

    def unlink(self, **kw):
        """Unlink object from bucket index.
        Args:
                kw(dict): Key/value pairs that needs to be provided to the installer
        Example::
        Supported keys:
                object(str): takes name of the object
                bucket(str): takes name of the bucket
        Returns:
            Dict(str)
            A mapping of host strings to the given task’s return value for that host’s execution run
        """
        kw = kw.get("kw")
        object_name = kw.get("object")
        bucket_name = kw.get("bucket")
        cmd = self.base_cmd + f" unlink --bucket={bucket_name} --object={object_name}"
        logger.info(f"Running command {cmd}")
        return fabfile.run_command(cmd, config=kw.get("env_config"))

    def rewrite(self, **kw):
        """Rewrite the specified object.
        Args:
                kw(dict): Key/value pairs that needs to be provided to the installer
        Example::
        Supported keys:
                object(str): takes name of the object
                bucket(str): takes name of the bucket
        Returns:
            Dict(str)
            A mapping of host strings to the given task’s return value for that host’s execution run
        """
        kw = kw.get("kw")
        object_name = kw.get("object")
        bucket_name = kw.get("bucket")
        cmd = self.base_cmd + f" rewrite --bucket={bucket_name} --object={object_name}"
        logger.info(f"Running command {cmd}")
        return fabfile.run_command(cmd, config=kw.get("env_config"))

    def expire_stale(self, **kw):
        """Run expired objects cleanup.
        Args:
                kw(dict): Key/value pairs that needs to be provided to the installer
        Example::
        Supported keys:
                bucket(str): takes name of the bucket
        Returns:
            Dict(str)
            A mapping of host strings to the given task’s return value for that host’s execution run
        """
        kw = kw.get("kw")
        self.base_cmd = self.base_cmd + "s"
        bucket_name = kw.get("bucket")
        if kw.get("list"):
            cmd = self.base_cmd + f" expire-stale list --bucket {bucket_name}"
        elif kw.get("rm"):
            cmd = self.base_cmd + f" expire-stale rm --bucket {bucket_name}"
        logger.info(f"Running command {cmd}")
        return fabfile.run_command(cmd, config=kw.get("env_config"))



import logging

from src.RhcsQeSdk.core.cli.radosgw_admin.bi import Bi
from src.RhcsQeSdk.core.cli.radosgw_admin.bucket import Bucket
from src.RhcsQeSdk.core.cli.radosgw_admin.caps import Caps
from src.RhcsQeSdk.core.cli.radosgw_admin.key import Key
from src.RhcsQeSdk.core.cli.radosgw_admin.log import Log
from src.RhcsQeSdk.core.cli.radosgw_admin.metadata import Metadata
from src.RhcsQeSdk.core.cli.radosgw_admin.object import Object
from src.RhcsQeSdk.core.cli.radosgw_admin.period import Period
from src.RhcsQeSdk.core.cli.radosgw_admin.pool import Pool
from src.RhcsQeSdk.core.cli.radosgw_admin.realm import Realm
from src.RhcsQeSdk.core.cli.radosgw_admin.reshard import Reshard
from src.RhcsQeSdk.core.cli.radosgw_admin.role import Role
from src.RhcsQeSdk.core.cli.radosgw_admin.role_policy import RolePolicy
from src.RhcsQeSdk.core.cli.radosgw_admin.subscription import Subscription
from src.RhcsQeSdk.core.cli.radosgw_admin.subuser import Subuser
from src.RhcsQeSdk.core.cli.radosgw_admin.topic import Topic
from src.RhcsQeSdk.core.cli.radosgw_admin.usage import Usage
from src.RhcsQeSdk.core.cli.radosgw_admin.user import User
from src.RhcsQeSdk.core.cli.radosgw_admin.zone import Zone
from src.RhcsQeSdk.core.cli.radosgw_admin.zonegroup import Zonegroup

logger = logging.getLogger(__name__)
logger.setLevel(logging.DEBUG)

formatter = logging.Formatter(
    "%(asctime)s - %(levelname)s - %(name)s:%(lineno)d - %(message)s"
)

stream_handler = logging.StreamHandler()
stream_handler.setFormatter(formatter)
stream_handler.setLevel(logging.DEBUG)
logger.addHandler(stream_handler)


class Radosgw_admin:
    """
    This module provides CLI interface to manage users, quotas, buckets, indexes,
    and all other aspects of the radosgw service.
    """

    def __init__(self, base_cmd=""):
        self.base_cmd = f"{base_cmd}radosgw-admin"
        self.zonegroup = Zonegroup(self.base_cmd)
        self.zone = Zone(self.base_cmd)
        self.topic = Topic(self.base_cmd)
        self.realm = Realm(self.base_cmd)
        self.bucket = Bucket(self.base_cmd)
        self.period = Period(self.base_cmd)
        self.user = User(self.base_cmd)
        self.subscription = Subscription(self.base_cmd)
        self.bi = Bi(self.base_cmd)
        self.usage = Usage(self.base_cmd)
        self.role = Role(self.base_cmd)
        self.role_policy = RolePolicy(self.base_cmd)
        self.key = Key(self.base_cmd)
        self.object = Object(self.base_cmd)
        self.caps = Caps(self.base_cmd)
        self.log = Log(self.base_cmd)
        self.pool = Pool(self.base_cmd)
        self.subuser = Subuser(self.base_cmd)
        self.reshard = Reshard(self.base_cmd)
        self.metadata = Metadata(self.base_cmd)



def merge_dicts(dict1, dict2):
    """
    Returns dict1 by recursively merging dict2 into dict1
    Args:
        dict1 (dict):     The dictionary corressponding to <deploy_cluster> test.
        dict2 (dict):     The dictionary corressponding to test scenarios of different component in ceph.
    Returns:
        Dict -> dictionary after merging dict1 with dict2
    """
    if isinstance(dict1, list) and isinstance(dict2, list):
        res = []
        extended_list = dict1 + dict2
        dict1 = [x for x in extended_list if x not in res]
        return dict1
    if not isinstance(dict1, dict) or not isinstance(dict2, dict):
        return dict2
    for k in dict2:
        if k in dict1:
            dict1[k] = merge_dicts(dict1[k], dict2[k])
        else:
            dict1[k] = dict2[k]
    return dict1



import logging

import src.RhcsQeSdk.core.cli.fabfile as fabfile

logger = logging.getLogger(__name__)
logger.setLevel(logging.DEBUG)

formatter = logging.Formatter(
    "%(asctime)s - %(levelname)s - %(name)s:%(lineno)d - %(message)s"
)

stream_handler = logging.StreamHandler()
stream_handler.setFormatter(formatter)
stream_handler.setLevel(logging.DEBUG)
logger.addHandler(stream_handler)


class Reshard:
    """
    This module provides CLI interface for commands of radosgw-admin reshard.
    """

    def __init__(self, base_cmd):
        self.base_cmd = base_cmd + " reshard"

    def add_(self, **kw):
        """Schedule a resharding of a bucket.
        Args:
                bucket_name(str) : Bucket name
                num_shards(str) : New number of shards
        Returns:
            Dict(str)
            A mapping of host strings to the given task’s return value for that host’s execution run
        """
        kw = kw.get("kw")
        bucket = kw.get("bucket_name", "")
        num_shards = kw.get("num_shards", "")
        cmd = self.base_cmd + " add" + f" --bucket {bucket} --num-shards {num_shards}"
        logger.info(f"Running commmand {cmd}")
        return fabfile.run_command(cmd, config=kw.get("env_config"))

    def list_(self, **kw):
        """List all bucket resharding or scheduled to be resharded.
        Args:
                None
        Returns:
            Dict(str)
            A mapping of host strings to the given task’s return value for that host’s execution run
        """
        kw = kw.get("kw")
        cmd = self.base_cmd + " list"
        logger.info(f"Running commmand {cmd}")
        return fabfile.run_command(cmd, config=kw.get("env_config"))

    def process(self, **kw):
        """Process of scheduled reshard jobs.
        Args:
                None
        Returns:
            Dict(str)
            A mapping of host strings to the given task’s return value for that host’s execution run
        """
        kw = kw.get("kw")
        cmd = self.base_cmd + " process"
        logger.info(f"Running commmand {cmd}")
        return fabfile.run_command(cmd, config=kw.get("env_config"))

    def status(self, **kw):
        """Resharding status of a bucket.
        Args:
                bucket_name(str) : Bucket name
        Returns:
            Dict(str)
            A mapping of host strings to the given task’s return value for that host’s execution run
        """
        kw = kw.get("kw")
        bucket = kw.get("bucket_name", "")
        cmd = self.base_cmd + " status" + f" --bucket {bucket}"
        logger.info(f"Running commmand {cmd}")
        return fabfile.run_command(cmd, config=kw.get("env_config"))

    def cancel(self, **kw):
        """Cancel resharding a bucket.
        Args:
                bucket_name(str) : Bucket name
        Returns:
            Dict(str)
            A mapping of host strings to the given task’s return value for that host’s execution run
        """
        kw = kw.get("kw")
        bucket = kw.get("bucket_name", "")
        cmd = self.base_cmd + " cancel" + f" --bucket {bucket}"
        logger.info(f"Running commmand {cmd}")
        return fabfile.run_command(cmd, config=kw.get("env_config"))
